﻿--[[
	LootTables.lua
	This file assigns a title to every loot table.  The primary use of this table
	is in the search function, as when iterating through the loot tables there is no
	inherant title to the loot table, given the origins of the mod as an Atlas plugin.
]]

--Invoke libraries
local AL = AceLibrary("AceLocale-2.2"):new("AtlasLoot");
local BC = AceLibrary("Babble-Class-2.2")
local BS = AceLibrary("Babble-Spell-2.2")
local BZ = AceLibrary("Babble-Zone-2.2")
local BB = AceLibrary("Babble-Boss-2.2")
local BF = AceLibrary("Babble-Faction-2.2")
local BIS = AceLibrary("Babble-ItemSet-2.2")

--Table of loot titles
AtlasLoot_TableNames = {
	
	--Keys
	["VanillaKeys"] = { AL["Keys"], "AtlasLootItems" },
	--Blackfathom Deeps
	["BFDGhamoora"] = { BB["Ghamoo-ra"], "AtlasLootItems" },
	["BFDLadySarevess"] = { BB["Lady Sarevess"], "AtlasLootItems" },
	["BFDGelihast"] = { BB["Gelihast"], "AtlasLootItems" },
	["BFDBaronAquanis"] = { BB["Baron Aquanis"], "AtlasLootItems" },
	["BFDTwilightLordKelris"] = { BB["Twilight Lord Kelris"], "AtlasLootItems" },
	["BFDOldSerrakis"] = { BB["Old Serra'kis"], "AtlasLootItems" },
	["BFDAkumai"] = { BB["Aku'mai"], "AtlasLootItems" },
	["BFDTrash"] = { AL["Trash Mobs"].." ("..BZ["Blackfathom Deeps"]..")", "AtlasLootItems" },
	--Blackrock Mountain
	["BRMScarshieldQuartermaster"] = { AL["Scarshield Quartermaster"], "AtlasLootItems" },
	--Blackrock Depths
	["BRDPyron"] = { AL["Overmaster Pyron"], "AtlasLootItems" },
	["BRDLordRoccor"] = { BB["Lord Roccor"], "AtlasLootItems" },
	["BRDHighInterrogatorGerstahn"] = { BB["High Interrogator Gerstahn"], "AtlasLootItems" },
	["BRDAnubshiah"] = { BB["Anub'shiah"], "AtlasLootItems" },
	["BRDEviscerator"] = { BB["Eviscerator"], "AtlasLootItems" },
	["BRDGorosh"] = { BB["Gorosh the Dervish"], "AtlasLootItems" },
	["BRDGrizzle"] = { BB["Grizzle"], "AtlasLootItems" },
	["BRDHedrum"] = { BB["Hedrum the Creeper"], "AtlasLootItems" },
	["BRDOkthor"] = { BB["Ok'thor the Breaker"], "AtlasLootItems" },
	["BRDTheldren"] = { AL["Theldren"], "AtlasLootItems" },
	["BRDHoundmaster"] = { BB["Houndmaster Grebmar"], "AtlasLootItems" },
	["BRDForgewright"] = { AL["Monument of Franclorn Forgewright"], "AtlasLootItems" },
	["BRDPyromancerLoregrain"] = { BB["Pyromancer Loregrain"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["BRDTheVault"] = { AL["The Vault"], "AtlasLootItems" },
	["BRDWarderStilgiss"] = { BB["Warder Stilgiss"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["BRDVerek"] = { BB["Verek"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["BRDFineousDarkvire"] = { BB["Fineous Darkvire"], "AtlasLootItems" },
	["BRDLordIncendius"] = { BB["Lord Incendius"], "AtlasLootItems" },
	["BRDBaelGar"] = { BB["Bael'Gar"], "AtlasLootItems" },
	["BRDGeneralAngerforge"] = { BB["General Angerforge"], "AtlasLootItems" },
	["BRDGolemLordArgelmach"] = { BB["Golem Lord Argelmach"], "AtlasLootItems" },
	["BRDGuzzler"] = { AL["The Grim Guzzler"], "AtlasLootItems" },
	["BRDFlamelash"] = { BB["Ambassador Flamelash"], "AtlasLootItems" },
	["BRDPanzor"] = { BB["Panzor the Invincible"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["BRDTomb"] = { "Summoner's Tomb", "AtlasLootItems" },
	["BRDLyceum"] = { AL["Shadowforge Flame Keeper"], "AtlasLootItems" },
	["BRDMagmus"] = { BB["Magmus"], "AtlasLootItems" },
	["BRDPrincess"] = { BB["Princess Moira Bronzebeard"], "AtlasLootItems" },
	["BRDEmperorDagranThaurissan"] = { BB["Emperor Dagran Thaurissan"], "AtlasLootItems" },
	["BRDBSPlans"] = { "Blacksmith Plans".." ("..BZ["Blackrock Depths"]..")", "AtlasLootItems" },
	["BRDTrash"] = { AL["Trash Mobs"].." ("..BZ["Blackrock Depths"]..")", "AtlasLootItems" },
	--Lower Blackrock Spire
	["LBRSSpirestoneButcher"] = { AL["Spirestone Butcher"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["LBRSPike"] = { AL["Roughshod Pike"], "AtlasLootItems" },
	["LBRSOmokk"] = { BB["Highlord Omokk"], "AtlasLootItems" },
	["LBRSSpirestoneBattleLord"] = { AL["Spirestone Battle Lord"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["LBRSSpirestoneLordMagus"] = { AL["Spirestone Lord Magus"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["LBRSVosh"] = { BB["Shadow Hunter Vosh'gajin"], "AtlasLootItems" },
	["LBRSVoone"] = { BB["War Master Voone"], "AtlasLootItems" },
	["LBRSGrayhoof"] = { BB["Mor Grayhoof"].." ("..AL["Summon"]..")", "AtlasLootItems" },
	["LBRSGrimaxe"] = { BB["Bannok Grimaxe"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["LBRSSmolderweb"] = { BB["Mother Smolderweb"], "AtlasLootItems" },
	["LBRSCrystalFang"] = { BB["Crystal Fang"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["LBRSHumanRemains"] = { AL["Human Remains"], "AtlasLootItems" },
	["LBRSDoomhowl"] = { BB["Urok Doomhowl"].." ("..AL["Summon"]..")", "AtlasLootItems" },
	["LBRSZigris"] = { BB["Quartermaster Zigris"], "AtlasLootItems" },
	["LBRSHalycon"] = { BB["Halycon"], "AtlasLootItems" },
	["LBRSSlavener"] = { BB["Gizrul the Slavener"], "AtlasLootItems" },
	["LBRSBashguud"] = { BB["Ghok Bashguud"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["LBRSWyrmthalak"] = { BB["Overlord Wyrmthalak"], "AtlasLootItems" },
	["LBRSFelguard"] = { AL["Burning Felguard"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["LBRSTrash"] = { AL["Trash Mobs"].." ("..BZ["Lower Blackrock Spire"]..")", "AtlasLootItems" },
	--Upper Blackrock Spire
	["UBRSEmberseer"] = { BB["Pyroguard Emberseer"], "AtlasLootItems" },
	["UBRSSolakar"] = { BB["Solakar Flamewreath"], "AtlasLootItems" },
	["UBRSFlame"] = { AL["Father Flame"], "AtlasLootItems" },
	["UBRSRunewatcher"] = { BB["Jed Runewatcher"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["UBRSAnvilcrack"] = { BB["Goraluk Anvilcrack"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["UBRSRend"] = { BB["Warchief Rend Blackhand"], "AtlasLootItems" },
	["UBRSGyth"] = { BB["Gyth"], "AtlasLootItems" },
	["UBRSBeast"] = { BB["The Beast"], "AtlasLootItems" },
	["UBRSValthalak"] = { BB["Lord Valthalak"].." ("..AL["Summon"]..")", "AtlasLootItems" },
	["UBRSDrakkisath"] = { BB["General Drakkisath"], "AtlasLootItems" },
	["UBRSTrash"] = { AL["Trash Mobs"].." ("..BZ["Upper Blackrock Spire"]..")", "AtlasLootItems" },
	--Blackwing Lair
	["BWLRazorgore"] = { BB["Razorgore the Untamed"], "AtlasLootItems" },
	["BWLVaelastrasz"] = { BB["Vaelastrasz the Corrupt"], "AtlasLootItems" },
	["BWLLashlayer"] = { BB["Broodlord Lashlayer"], "AtlasLootItems" },
	["BWLFiremaw"] = { BB["Firemaw"], "AtlasLootItems" },
	["BWLEbonroc"] = { BB["Ebonroc"], "AtlasLootItems" },
	["BWLFlamegor"] = { BB["Flamegor"], "AtlasLootItems" },
	["BWLChromaggus"] = { BB["Chromaggus"], "AtlasLootItems" },
	["BWLNefarian"] = { BB["Nefarian"], "AtlasLootItems" },
	["BWLTrashMobs"] = { AL["Trash Mobs"].." ("..BZ["Blackwing Lair"]..")", "AtlasLootItems" },
	--The Deadmines
	["DMMarisaduPaige"] = { AL["Marisa du'Paige"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["DMBrainwashedNoble"] = { AL["Brainwashed Noble"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["DMForemanThistlenettle"] = { AL["Foreman Thistlenettle"], "AtlasLootItems" },
	["DMRhahkZor"] = { BB["Rhahk'Zor"], "AtlasLootItems" },
	["DMMinerJohnson"] = { BB["Miner Johnson"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["DMSneed"] = { BB["Sneed"], "AtlasLootItems" },
	["DMSneedsShredder"] = { AL["Sneed's Shredder"], "AtlasLootItems" },
	["DMGilnid"] = { BB["Gilnid"], "AtlasLootItems" },
	["DMDefiasGunpowder"] = { AL["Defias Gunpowder"], "AtlasLootItems" },
	["DMMrSmite"] = { BB["Mr. Smite"], "AtlasLootItems" },
	["DMCookie"] = { BB["Cookie"], "AtlasLootItems" },
	["DMCaptainGreenskin"] = { BB["Captain Greenskin"], "AtlasLootItems" },
	["DMVanCleef"] = { BB["Edwin VanCleef"], "AtlasLootItems" },
	["DMTrash"] = { AL["Trash Mobs"].." ("..BZ["The Deadmines"]..")", "AtlasLootItems" },
	--Dire Maul East
	["DMEPusillin"] = { BB["Pusillin"], "AtlasLootItems" },
	["DMEZevrimThornhoof"] = { BB["Zevrim Thornhoof"], "AtlasLootItems" },
	["DMEHydro"] = { BB["Hydrospawn"], "AtlasLootItems" },
	["DMELethtendris"] = { BB["Lethtendris"], "AtlasLootItems" },
	["DMEPimgib"] = { BB["Pimgib"], "AtlasLootItems" },
	["DMEAlzzin"] = { BB["Alzzin the Wildshaper"], "AtlasLootItems" },
	["DMEIsalien"] = { BB["Isalien"], "AtlasLootItems" },
	["DMETrash"] = { AL["Trash Mobs"].." ("..BZ["Dire Maul (East)"]..")", "AtlasLootItems" },
	["DMEShard"] = { AL["Felvine Shard"], "AtlasLootItems" },
	["DMTome"] = { AL["A Dusty Tome"], "AtlasLootItems" },
	["DMBooks"] = { "Dire Maul Books", "AtlasLootItems" },
	--Dire Maul North
	["DMNGuardMoldar"] = { BB["Guard Mol'dar"], "AtlasLootItems" },
	["DMNStomperKreeg"] = { AL["Stomper Kreeg"], "AtlasLootItems" },
	["DMNGuardFengus"] = { BB["Guard Fengus"], "AtlasLootItems" },
	["DMNThimblejack"] = { AL["Knot Thimblejack"], "AtlasLootItems" },
	["DMNGuardSlipkik"] = { BB["Guard Slip'kik"], "AtlasLootItems" },
	["DMNCaptainKromcrush"] = { BB["Captain Kromcrush"], "AtlasLootItems" },
	["DMNChoRush"] = { BB["Cho'Rush the Observer"], "AtlasLootItems" },
	["DMNKingGordok"] = { BB["King Gordok"], "AtlasLootItems" },
	["DMNTrash"] = { AL["Trash Mobs"].." ("..BZ["Dire Maul (North)"]..")", "AtlasLootItems" },
	["DMNTRIBUTERUN"] = { AL["Tribute Chest"], "AtlasLootItems" },
	--Dire Maul West
	["DMWTendrisWarpwood"] = { BB["Tendris Warpwood"], "AtlasLootItems" },
	["DMWIllyannaRavenoak"] = { BB["Illyanna Ravenoak"], "AtlasLootItems" },
	["DMWMagisterKalendris"] = { BB["Magister Kalendris"], "AtlasLootItems" },
	["DMWTsuzee"] = { BB["Tsu'zee"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["DMWRevanchion"] = { BB["Revanchion"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
	["DMWImmolthar"] = { BB["Immol'thar"], "AtlasLootItems" },
	["DMWHelnurath"] = { BB["Lord Hel'nurath"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["DMWPrinceTortheldrin"] = { BB["Prince Tortheldrin"], "AtlasLootItems" },
	["DMWShendralarProvisioner"] = { AL["Shen'dralar Provisioner"], "AtlasLootItems" },
	["DMWTrash"] = { AL["Trash Mobs"].." ("..BZ["Dire Maul (West)"]..")", "AtlasLootItems" },
	--Gnomeregan
	["GnNamdoBizzfizzle"] = { AL["Namdo Bizzfizzle"], "AtlasLootItems" },
	["GnTechbot"] = { AL["Techbot"], "AtlasLootItems" },
	["GnGrubbis"] = { BB["Grubbis"], "AtlasLootItems" },
	["GnViscousFallout"] = { BB["Viscous Fallout"], "AtlasLootItems" },
	["GnElectrocutioner6000"] = { BB["Electrocutioner 6000"], "AtlasLootItems" },
	["GnCrowdPummeler960"] = { BB["Crowd Pummeler 9-60"], "AtlasLootItems" },
	["GnDIAmbassador"] = { BB["Dark Iron Ambassador"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["GnMekgineerThermaplugg"] = { BB["Mekgineer Thermaplugg"], "AtlasLootItems" },
	["GnTrash"] = { AL["Trash Mobs"].." ("..BZ["Gnomeregan"]..")", "AtlasLootItems" },
	["GnOutsideTrash"] = { AL["Trash Mobs"].." ("..BZ["Gnomeregan"].." "..AL["Entrance"]..")", "AtlasLootItems" },
	["GnPunchographA"] = { AL["Matrix Punchograph 3005-A"], "AtlasLootItems" },
	["GnPunchographB"] = { AL["Matrix Punchograph 3005-B"], "AtlasLootItems" },
	["GnPunchographC"] = { AL["Matrix Punchograph 3005-C"], "AtlasLootItems" },
	["GnPunchographD"] = { AL["Matrix Punchograph 3005-D"], "AtlasLootItems" },
	--Maraudon
	["MaraNamelesProphet"] = { AL["The Nameles Prophet"], "AtlasLootItems" },
	["MaraKhanKolk"] = { AL["Kolk"].." (The First Khan)", "AtlasLootItems" },
	["MaraKhanGelk"] = { AL["Gelk"].." (The Second Khan)", "AtlasLootItems" },
	["MaraKhanMagra"] = { AL["Magra"].." (The Third Khan)", "AtlasLootItems" },
	["MaraKhanVeng"] = { AL["Veng"].." (The Fifth Khan)", "AtlasLootItems" },
	["MaraNoxxion"] = { BB["Noxxion"], "AtlasLootItems" },
	["MaraRazorlash"] = { BB["Razorlash"], "AtlasLootItems" },
	["MaraKhanMaraudos"] = { AL["Maraudos"].." (The Forth Khan)", "AtlasLootItems" },
	["MaraLordVyletongue"] = { BB["Lord Vyletongue"], "AtlasLootItems" },
	["MaraMeshlok"] = { BB["Meshlok the Harvester"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["MaraCelebras"] = { BB["Celebras the Cursed"], "AtlasLootItems" },
	["MaraLandslide"] = { BB["Landslide"], "AtlasLootItems" },
	["MaraTinkererGizlock"] = { BB["Tinkerer Gizlock"], "AtlasLootItems" },
	["MaraRotgrip"] = { BB["Rotgrip"], "AtlasLootItems" },
	["MaraPrincessTheradras"] = { BB["Princess Theradras"], "AtlasLootItems" },
	--Molten Core
	["MCLucifron"] = { BB["Lucifron"], "AtlasLootItems" },
	["MCMagmadar"] = { BB["Magmadar"], "AtlasLootItems" },
	["MCGehennas"] = { BB["Gehennas"], "AtlasLootItems" },
	["MCGarr"] = { BB["Garr"], "AtlasLootItems" },
	["MCShazzrah"] = { BB["Shazzrah"], "AtlasLootItems" },
	["MCGeddon"] = { BB["Baron Geddon"], "AtlasLootItems" },
	["MCGolemagg"] = { BB["Golemagg the Incinerator"], "AtlasLootItems" },
	["MCSulfuron"] = { BB["Sulfuron Harbinger"], "AtlasLootItems" },
	["MCMajordomo"] = { BB["Majordomo Executus"], "AtlasLootItems" },
	["MCRagnaros"] = { BB["Ragnaros"], "AtlasLootItems" },
	["MCRANDOMBOSSDROPS"] = { "Random Boss Drops", "AtlasLootItems" },
	["MCTrashMobs"] = { AL["Trash Mobs"].." ("..BZ["Molten Core"]..")", "AtlasLootItems" },
	--Naxxramas
	["NAXPatchwerk"] = { BB["Patchwerk"], "AtlasLootItems" },
	["NAXGrobbulus"] = { BB["Grobbulus"], "AtlasLootItems" },
	["NAXGluth"] = { BB["Gluth"], "AtlasLootItems" },
	["NAXThaddius"] = { BB["Thaddius"], "AtlasLootItems" },
	["NAXAnubRekhan"] = { BB["Anub'Rekhan"], "AtlasLootItems" },
	["NAXGrandWidowFaerlina"] = { BB["Grand Widow Faerlina"], "AtlasLootItems" },
	["NAXMaexxna"] = { BB["Maexxna"], "AtlasLootItems" },
	["NAXInstructorRazuvious"] = { BB["Instructor Razuvious"], "AtlasLootItems" },
	["NAXGothiktheHarvester"] = { BB["Gothik the Harvester"], "AtlasLootItems" },
	["NAXTheFourHorsemen"] = { BB["The Four Horsemen"], "AtlasLootItems" },
	["NAXNoththePlaguebringer"] = { BB["Noth the Plaguebringer"], "AtlasLootItems" },
	["NAXHeigantheUnclean"] = { BB["Heigan the Unclean"], "AtlasLootItems" },
	["NAXLoatheb"] = { BB["Loatheb"], "AtlasLootItems" },
	["NAXSapphiron"] = { BB["Sapphiron"], "AtlasLootItems" },
	["NAXKelThuzard"] = { BB["Kel'Thuzad"], "AtlasLootItems" },
	["NAXTrash"] = { AL["Trash Mobs"].." ("..BZ["Naxxramas"]..")", "AtlasLootItems" },
	--Onyxia's Lair
	["Onyxia"] = { BB["Onyxia"], "AtlasLootItems" },
	--Ragefire Chasm
	["RFCTaragaman"] = { BB["Taragaman the Hungerer"], "AtlasLootItems" },
	["RFCJergosh"] = { BB["Jergosh the Invoker"], "AtlasLootItems" },
	--Razorfen Downs
	["RFDTutenkash"] = { BB["Tuten'kash"], "AtlasLootItems" },
	["RFDHenryStern"] = { AL["Henry Stern"], "AtlasLootItems" },
	["RFDLadyF"] = { BB["Lady Falther'ess"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
	["RFDMordreshFireEye"] = { BB["Mordresh Fire Eye"], "AtlasLootItems" },
	["RFDGlutton"] = { BB["Glutton"], "AtlasLootItems" },
	["RFDRagglesnout"] = { BB["Ragglesnout"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["RFDAmnennar"] = { BB["Amnennar the Coldbringer"], "AtlasLootItems" },
	["RFDPlaguemaw"] = { BB["Plaguemaw the Rotting"], "AtlasLootItems" },
	["RFDTrash"] = { AL["Trash Mobs"].." ("..BZ["Razorfen Downs"]..")", "AtlasLootItems" },
	--Razorfen Kraul
	["RFKAggem"] = { BB["Aggem Thorncurse"], "AtlasLootItems" },
	["RFKDeathSpeakerJargba"] = { BB["Death Speaker Jargba"], "AtlasLootItems" },
	["RFKRazorfenSpearhide"] = { AL["Razorfen Spearhide"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["RFKOverlordRamtusk"] = { BB["Overlord Ramtusk"], "AtlasLootItems" },
	["RFKAgathelos"] = { BB["Agathelos the Raging"], "AtlasLootItems" },
	["RFKBlindHunter"] = { BB["Blind Hunter"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["RFKCharlgaRazorflank"] = { BB["Charlga Razorflank"], "AtlasLootItems" },
	["RFKEarthcallerHalmgar"] = { BB["Earthcaller Halmgar"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["RFKRoogug"] = { BB["Roogug"], "AtlasLootItems" },
	["RFKTrash"] = { AL["Trash Mobs"].." ("..BZ["Razorfen Kraul"]..")", "AtlasLootItems" },
	--The Ruins of Ahn'Qiraj
	["AQ20Kurinnaxx"] = { BB["Kurinnaxx"], "AtlasLootItems" },
	["AQ20Andorov"] = { BB["Lieutenant General Andorov"], "AtlasLootItems" },
	["AQ20CAPTAIN"] = { AL["Rajaxx's Captains"], "AtlasLootItems" },
	["AQ20Rajaxx"] = { BB["General Rajaxx"], "AtlasLootItems" },
	["AQ20Moam"] = { BB["Moam"], "AtlasLootItems" },
	["AQ20Buru"] = { BB["Buru the Gorger"], "AtlasLootItems" },
	["AQ20Ayamiss"] = { BB["Ayamiss the Hunter"], "AtlasLootItems" },
	["AQ20Ossirian"] = { BB["Ossirian the Unscarred"], "AtlasLootItems" },
	["AQ20Trash"] = { AL["Trash Mobs"].." (AQ20)", "AtlasLootItems" },
	["AQ20ClassBooks"] = { "AQ Class Books", "AtlasLootItems" },
	["AQEnchants"] = { "AQ Enchants", "AtlasLootItems" },
	--Scarlet Monastery - Armory
	["SMHerod"] = { BB["Herod"], "AtlasLootItems" },
	["SMATrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Armory"]..")", "AtlasLootItems" },
	--Scarlet Monastery - Cathedral
	["SMFairbanks"] = { BB["High Inquisitor Fairbanks"], "AtlasLootItems" },
	["SMMograine"] = { BB["Scarlet Commander Mograine"], "AtlasLootItems" },
	["SMWhitemane"] = { BB["High Inquisitor Whitemane"], "AtlasLootItems" },
	["SMCTrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Cathedral"]..")", "AtlasLootItems" },
	--Scarlet Monastery - Graveyard
	["SMVishas"] = { BB["Interrogator Vishas"], "AtlasLootItems" },
	["SMScorn"] = { BB["Scorn"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
	["SMIronspine"] = { BB["Ironspine"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["SMAzshir"] = { BB["Azshir the Sleepless"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["SMFallenChampion"] = { BB["Fallen Champion"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["SMBloodmageThalnos"] = { BB["Bloodmage Thalnos"], "AtlasLootItems" },
	["SMGTrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Graveyard"]..")", "AtlasLootItems" },
	--Scarlet Monastery - Library
	["SMHoundmasterLoksey"] = { BB["Houndmaster Loksey"], "AtlasLootItems" },
	["SMDoan"] = { BB["Arcanist Doan"], "AtlasLootItems" },
	["SMDoansBox"] = { AL["Doan's Strongbox"], "AtlasLootItems" },
	["SMLTrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Library"]..")", "AtlasLootItems" },
	--Scholomance
	["SCHOLOBlood"] = { AL["Blood Steward of Kirtonos"], "AtlasLootItems" },
	["SCHOLOKirtonostheHerald"] = { BB["Kirtonos the Herald"], "AtlasLootItems" },
	["SCHOLOJandiceBarov"] = { BB["Jandice Barov"], "AtlasLootItems" },
	["SCHOLOLordBlackwood"] = { BB["Lord Blackwood"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
	["SCHOLORattlegore"] = { BB["Rattlegore"], "AtlasLootItems" },
	["SCHOLODeathKnight"] = { BB["Death Knight Darkreaver"], "AtlasLootItems" },
	["SCHOLOMarduk"] = { BB["Marduk Blackpool"], "AtlasLootItems" },
	["SCHOLOVectus"] = { BB["Vectus"], "AtlasLootItems" },
	["SCHOLORasFrostwhisper"] = { BB["Ras Frostwhisper"], "AtlasLootItems" },
	["SCHOLOKormok"] = { BB["Kormok"], "AtlasLootItems" },
	["SCHOLOInstructorMalicia"] = { BB["Instructor Malicia"], "AtlasLootItems" },
	["SCHOLODoctorTheolenKrastinov"] = { BB["Doctor Theolen Krastinov"], "AtlasLootItems" },
	["SCHOLOLorekeeperPolkelt"] = { BB["Lorekeeper Polkelt"], "AtlasLootItems" },
	["SCHOLOTheRavenian"] = { BB["The Ravenian"], "AtlasLootItems" },
	["SCHOLOLordAlexeiBarov"] = { BB["Lord Alexei Barov"], "AtlasLootItems" },
	["SCHOLOLadyIlluciaBarov"] = { BB["Lady Illucia Barov"], "AtlasLootItems" },
	["SCHOLODarkmasterGandling"] = { BB["Darkmaster Gandling"], "AtlasLootItems" },
	["SCHOLOTrash"] = { AL["Trash Mobs"].." ("..BZ["Scholomance"]..")", "AtlasLootItems" },
	--Shadowfang Keep
	["SFKRethilgore"] = { BB["Rethilgore"], "AtlasLootItems" },
	["SFKFelSteed"] = { AL["Fel Steed"], "AtlasLootItems" },
	["SFKJordansHammer"] = { AL["Jordan's Hammer"], "AtlasLootItems" },
	["SFKRazorclawtheButcher"] = { BB["Razorclaw the Butcher"], "AtlasLootItems" },
	["SFKSilverlaine"] = { BB["Baron Silverlaine"], "AtlasLootItems" },
	["SFKSpringvale"] = { BB["Commander Springvale"], "AtlasLootItems" },
	["SFKSever"] = { BB["Sever"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
	["SFKOdotheBlindwatcher"] = { BB["Odo the Blindwatcher"], "AtlasLootItems" },
	["SFKFenrustheDevourer"] = { BB["Fenrus the Devourer"], "AtlasLootItems" },
	["SFKBookofUr"] = { AL["The Book of Ur"], "AtlasLootItems" },
	["SFKArugalsVoidwalker"] = { AL["Arugal's Voidwalker"], "AtlasLootItems" },
	["SFKWolfMasterNandos"] = { BB["Wolf Master Nandos"], "AtlasLootItems" },
	["SFKArchmageArugal"] = { BB["Archmage Arugal"], "AtlasLootItems" },
	["SFKDeathswornCaptain"] = { BB["Deathsworn Captain"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["SFKTrash"] = { AL["Trash Mobs"].." ("..BZ["Shadowfang Keep"]..")", "AtlasLootItems" },
	--The Stockade
	["SWStKamDeepfury"] = { BB["Kam Deepfury"], "AtlasLootItems" },
	["SWStBruegalIronknuckle"] = { BB["Bruegal Ironknuckle"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["SWStTrash"] = { AL["Trash Mobs"].." ("..BZ["The Stockade"]..")", "AtlasLootItems" },
	--Stratholme
	["STRATSkull"] = { BB["Skul"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["STRATStratholmeCourier"] = { BB["Stratholme Courier"], "AtlasLootItems" },
	["STRATPostmaster"] = { BB["Postmaster Malown"], "AtlasLootItems" },
	["STRATFrasSiabi"] = { AL["Fras Siabi"], "AtlasLootItems" },
	["STRATAtiesh"] = { "Atiesh", "AtlasLootItems" },
	["STRATBalzaphon"] = { BB["Balzaphon"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
	["STRATHearthsingerForresten"] = { BB["Hearthsinger Forresten"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["STRATTheUnforgiven"] = { BB["The Unforgiven"], "AtlasLootItems" },
	["STRATTimmytheCruel"] = { BB["Timmy the Cruel"], "AtlasLootItems" },
	["STRATMalorsStrongbox"] = { AL["Malor's Strongbox"], "AtlasLootItems" },
	["STRATCrimsonHammersmith"] = { AL["Crimson Hammersmith"].." ("..AL["Summon"]..")", "AtlasLootItems" },
	["STRATBSPlansSerenity"] = { "Plans: Serenity", "AtlasLootItems" },
	["STRATCannonMasterWilley"] = { BB["Cannon Master Willey"], "AtlasLootItems" },
	["STRATArchivistGalford"] = { BB["Archivist Galford"], "AtlasLootItems" },
	["STRATBalnazzar"] = { BB["Balnazzar"], "AtlasLootItems" },
	["STRATSothosJarien"] = { BB["Sothos"].." & "..BB["Jarien"], "AtlasLootItems" },
	["STRATStonespine"] = { BB["Stonespine"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["STRATNerubenkan"] = { BB["Nerub'enkan"], "AtlasLootItems" },
	["STRATBaronessAnastari"] = { BB["Baroness Anastari"], "AtlasLootItems" },
	["STRATBlackGuardSwordsmith"] = { AL["Black Guard Swordsmith"].." ("..AL["Summon"]..")", "AtlasLootItems" },
	["STRATBSPlansCorruption"] = { "Plans: Corruption", "AtlasLootItems" },
	["STRATMalekithePallid"] = { BB["Maleki the Pallid"], "AtlasLootItems" },
	["STRATMagistrateBarthilas"] = { BB["Magistrate Barthilas"], "AtlasLootItems" },
	["STRATRamsteintheGorger"] = { BB["Ramstein the Gorger"], "AtlasLootItems" },
	["STRATBaronRivendare"] = { BB["Baron Rivendare"], "AtlasLootItems" },
	["STRATTrash"] = { AL["Trash Mobs"].." ("..BZ["Stratholme"]..")", "AtlasLootItems" },
	--Sunken Temple
	["STSpawnOfHakkar"] = { AL["Spawn of Hakkar"], "AtlasLootItems" },
	["STBalconyMinibosses"] = { AL["Balcony Minibosses"], "AtlasLootItems" },
	["STAtalalarion"] = { BB["Atal'alarion"], "AtlasLootItems" },
	["STDreamscythe"] = { BB["Dreamscythe"], "AtlasLootItems" },
	["STWeaver"] = { BB["Weaver"], "AtlasLootItems" },
	["STAvatarofHakkar"] = { BB["Avatar of Hakkar"], "AtlasLootItems" },
	["STJammalan"] = { BB["Jammal'an the Prophet"], "AtlasLootItems" },
	["STOgom"] = { BB["Ogom the Wretched"], "AtlasLootItems" },
	["STMorphaz"] = { BB["Morphaz"], "AtlasLootItems" },
	["STHazzas"] = { BB["Hazzas"], "AtlasLootItems" },
	["STEranikus"] = { BB["Shade of Eranikus"], "AtlasLootItems" },
	["STTrash"] = { AL["Trash Mobs"].." ("..AL["The Sunken Temple"]..")", "AtlasLootItems" },
	--Temple of Ahn'Qiraj
	["AQ40Skeram"] = { BB["The Prophet Skeram"], "AtlasLootItems" },
	["AQ40Trio"] = { AL["The Bug Family"], "AtlasLootItems" },
	["AQ40Sartura"] = { BB["Battleguard Sartura"], "AtlasLootItems" },
	["AQ40Fankriss"] = { BB["Fankriss the Unyielding"], "AtlasLootItems" },
	["AQ40Viscidus"] = { BB["Viscidus"], "AtlasLootItems" },
	["AQ40Huhuran"] = { BB["Princess Huhuran"], "AtlasLootItems" },
	["AQ40Emperors"] = { BB["The Twin Emperors"], "AtlasLootItems" },
	["AQ40Ouro"] = { BB["Ouro"], "AtlasLootItems" },
	["AQ40CThun"] = { BB["C'Thun"], "AtlasLootItems" },
	["AQ40Trash1"] = { AL["Trash Mobs"].." (AQ40)", "AtlasLootItems" },
	["AQ40Trash2"] = { AL["Trash Mobs"].." (AQ40)", "AtlasLootItems" },
	["AQOpening"] = { "AQ Opening Quest Line", "AtlasLootItems" },
	--Uldaman
	["UldMagreganDeepshadow"] = { AL["Magregan Deepshadow"], "AtlasLootItems" },
	["UldTabletofRyuneh"] = { "Tablet of Ryun'eh", "AtlasLootItems" },
	["UldKromStoutarmChest"] = { AL["Krom Stoutarm's Chest"], "AtlasLootItems" },
	["UldGarrettFamilyChest"] = { AL["Garrett Family Chest"], "AtlasLootItems" },
	["UldShovelphlange"] = { AL["Digmaster Shovelphlange"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["UldRevelosh"] = { BB["Revelosh"], "AtlasLootItems" },
	["UldEric"] = { BB["Baelog"], "AtlasLootItems" },
	["UldOlaf"] = { BB["Baelog"], "AtlasLootItems" },
	["UldBaelog"] = { BB["Baelog"], "AtlasLootItems" },
	["UldBaelogsChest"] = { BB["Baelog"], "AtlasLootItems" },
	["UldIronaya"] = { BB["Ironaya"], "AtlasLootItems" },
	["UldObsidianSentinel"] = { BB["Obsidian Sentinel"], "AtlasLootItems" },
	["UldAncientStoneKeeper"] = { BB["Ancient Stone Keeper"], "AtlasLootItems" },
	["UldGalgannFirehammer"] = { BB["Galgann Firehammer"], "AtlasLootItems" },
	["UldTabletofWill"] = { "Tablet of Will", "AtlasLootItems" },
	["UldShadowforgeCache"] = { "Shadowforge Cache", "AtlasLootItems" },
	["UldGrimlok"] = { BB["Grimlok"], "AtlasLootItems" },
	["UldArchaedas"] = { BB["Archaedas"], "AtlasLootItems" },
	["UldTrash"] = { AL["Trash Mobs"].." ("..BZ["Uldaman"]..")", "AtlasLootItems" },
	--Wailing Caverns
	["WCKalldanFelmoon"] = { AL["Kalldan Felmoon"], "AtlasLootItems" },
	["WCMadMagglish"] = { AL["Mad Magglish"], "AtlasLootItems" },
	["WCTrigoretheLasher"] = { AL["Trigore the Lasher"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["WCBoahn"] = { AL["Boahn"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["WCLordCobrahn"] = { BB["Lord Cobrahn"], "AtlasLootItems" },
	["WCLadyAnacondra"] = { BB["Lady Anacondra"], "AtlasLootItems" },
	["WCKresh"] = { BB["Kresh"], "AtlasLootItems" },
	["WCLordPythas"] = { BB["Lord Pythas"], "AtlasLootItems" },
	["WCSkum"] = { BB["Skum"], "AtlasLootItems" },
	["WCLordSerpentis"] = { BB["Lord Serpentis"], "AtlasLootItems" },
	["WCVerdan"] = { BB["Verdan the Everliving"], "AtlasLootItems" },
	["WCMutanus"] = { BB["Mutanus the Devourer"], "AtlasLootItems" },
	["WCDeviateFaerieDragon"] = { BB["Deviate Faerie Dragon"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["WCTrash"] = { AL["Trash Mobs"].." ("..BZ["Wailing Caverns"]..")", "AtlasLootItems" },
	--Zul'Farrak
	["ZFAntusul"] = { BB["Antu'sul"], "AtlasLootItems" },
	["ZFThekatheMartyr"] = { AL["Theka the Martyr"], "AtlasLootItems" },
	["ZFWitchDoctorZumrah"] = { BB["Witch Doctor Zum'rah"], "AtlasLootItems" },
	["ZFNekrumGutchewer"] = { AL["Nekrum Gutchewer"], "AtlasLootItems" },
	["ZFSezzziz"] = { BB["Shadowpriest Sezz'ziz"], "AtlasLootItems" },
	["ZFDustwraith"] = { AL["Dustwraith"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["ZFSergeantBly"] = { AL["Sergeant Bly"], "AtlasLootItems" },
	["ZFSandfury"] = { AL["Sandfury Executioner"], "AtlasLootItems" },
	["ZFHydromancerVelratha"] = { AL["Hydromancer Velratha"], "AtlasLootItems" },
	["ZFGahzrilla"] = { BB["Gahz'rilla"], "AtlasLootItems" },
	["ZFChiefUkorzSandscalp"] = { BB["Chief Ukorz Sandscalp"], "AtlasLootItems" },
	["ZFZerillis"] = { AL["Zerillis"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	["ZFTrash"] = { AL["Trash Mobs"].." ("..BZ["Zul'Farrak"]..")", "AtlasLootItems" },
	--Zul'Gurub
	["ZGJeklik"] = { BB["High Priestess Jeklik"], "AtlasLootItems" },
	["ZGVenoxis"] = { BB["High Priest Venoxis"], "AtlasLootItems" },
	["ZGMarli"] = { BB["High Priestess Mar'li"], "AtlasLootItems" },
	["ZGMandokir"] = { BB["Bloodlord Mandokir"], "AtlasLootItems" },
	["ZGGrilek"] = { BB["Gri'lek"], "AtlasLootItems" },
	["ZGHazzarah"] = { BB["Hazza'rah"], "AtlasLootItems" },
	["ZGRenataki"] = { BB["Renataki"], "AtlasLootItems" },
	["ZGWushoolay"] = { BB["Wushoolay"], "AtlasLootItems" },
	["ZGGahzranka"] = { BB["Gahz'ranka"], "AtlasLootItems" },
	["ZGThekal"] = { BB["High Priest Thekal"], "AtlasLootItems" },
	["ZGArlokk"] = { BB["High Priestess Arlokk"], "AtlasLootItems" },
	["ZGJindo"] = { BB["Jin'do the Hexxer"], "AtlasLootItems" },
	["ZGHakkar"] = { BB["Hakkar"], "AtlasLootItems" },
	["ZGMuddyChurningWaters"] = { AL["Muddy Churning Waters"], "AtlasLootItems" },
	["ZGJinxedHoodooPile"] = { AL["Jinxed Hoodoo Pile"], "AtlasLootItems" },
	["ZGShared"] = { "Shared ZG Priest Drops", "AtlasLootItems" },
	["ZGTrash1"] = { AL["Trash Mobs"].." ("..BZ["Zul'Gurub"]..")", "AtlasLootItems" },
	["ZGTrash2"] = { AL["Trash Mobs"].." ("..BZ["Zul'Gurub"]..")", "AtlasLootItems" },
	["ZGEnchants"] = { "ZG Enchants", "AtlasLootItems" },
	
	------------
	--- Sets ---
	------------
	
	--Vanilla WoW Sets
	["DEADMINES"] = { AL["Set: "]..BIS["Defias Leather"], "AtlasLootSetItems" },
	["WAILING"] = { AL["Set: "]..BIS["Embrace of the Viper"], "AtlasLootSetItems" },
	["SCARLET"] = { AL["Set: "]..BIS["Chain of the Scarlet Crusade"], "AtlasLootSetItems" },
	["BLACKROCKD"] = { AL["Set: "]..BIS["The Gladiator"], "AtlasLootSetItems" },
	["IRONWEAVE"] = { AL["Set: "]..BIS["Ironweave Battlesuit"], "AtlasLootSetItems" },
	["ScholoCloth"] = { AL["Set: "]..BIS["Necropile Raiment"], "AtlasLootSetItems" },
	["ScholoLeather"] = { AL["Set: "]..BIS["Cadaverous Garb"], "AtlasLootSetItems" },
	["ScholoMail"] = { AL["Set: "]..BIS["Bloodmail Regalia"], "AtlasLootSetItems" },
	["ScholoPlate"] = { AL["Set: "]..BIS["Deathbone Guardian"], "AtlasLootSetItems" },
	["STRAT"] = { AL["Set: "]..BIS["The Postmaster"], "AtlasLootSetItems" },
	["SpiderKiss"] = { AL["Set: "]..BIS["Spider's Kiss"], "AtlasLootSetItems" },
	["DalRend"] = { AL["Set: "]..BIS["Dal'Rend's Arms"], "AtlasLootSetItems" },
	["ZGRings"] = { AL["Set: "]..AL["Zul'Gurub Rings"], "AtlasLootSetItems" },
	["ShardOfGods"] = { AL["Set: "]..BIS["Shard of the Gods"], "AtlasLootSetItems" },
	["SpiritofEskhandar"] = { AL["Set: "]..BIS["Spirit of Eskhandar"], "AtlasLootSetItems" },
	["HakkariBlades"] = { AL["Set: "]..BIS["The Twin Blades of Hakkari"], "AtlasLootSetItems" },
	["PrimalBlessing"] = { AL["Set: "]..BIS["Primal Blessing"], "AtlasLootSetItems" },
	["ScourgeInvasion"] = { AL["Set: "]..AL["Scourge Invasion"], "AtlasLootSetItems" },
	["Legendaries"] = { AL["Set: "]..AL["Legendary Items"], "AtlasLootSetItems" },
	["Artifacts"] = { AL["Set: "]..AL["Artifact Items"], "AtlasLootSetItems" },
	["RareMounts"] = { AL["Rare Mounts"], "AtlasLootSetItems" },
	["OldMounts"] = { AL["Old Mounts"], "AtlasLootSetItems" },
	["PvPMountsSets"] = { AL["PvP Mounts"], "AtlasLootSetItems" },
	["UnobMounts"] = { AL["Unobtainable Mounts"], "AtlasLootSetItems" },
	["Tabards"] = { AL["Tabards"], "AtlasLootSetItems" },
	["RarePets1"] = { AL["Rare Pets"], "AtlasLootSetItems" },
	["RarePets2"] = { AL["Rare Pets"], "AtlasLootSetItems" },
	--Crafted Sets - Blacksmithing
	["ImperialPlate"] = { BIS["Imperial Plate"], "AtlasLootCrafting" },
	["TheDarksoul"] = { BIS["The Darksoul"], "AtlasLootCrafting" },
	["BloodsoulEmbrace"] = { BIS["Bloodsoul Embrace"], "AtlasLootCrafting" },
	--Crafted Sets - Tailoring
	["BloodvineG"] = { BIS["Bloodvine Garb"], "AtlasLootCrafting" },
	--Crafted Sets - Leatherworking
	["VolcanicArmor"] = { BIS["Volcanic Armor"], "AtlasLootCrafting" },
	["IronfeatherArmor"] = { BIS["Ironfeather Armor"], "AtlasLootCrafting" },
	["StormshroudArmor"] = { BIS["Stormshroud Armor"], "AtlasLootCrafting" },
	["DevilsaurArmor"] = { BIS["Devilsaur Armor"], "AtlasLootCrafting" },
	["BloodTigerH"] = { BIS["Blood Tiger Harness"], "AtlasLootCrafting" },
	["PrimalBatskin"] = { BIS["Primal Batskin"], "AtlasLootCrafting" },
	["GreenDragonM"] = { BIS["Green Dragon Mail"], "AtlasLootCrafting" },
	["BlueDragonM"] = { BIS["Blue Dragon Mail"], "AtlasLootCrafting" },
	["BlackDragonM"] = { BIS["Black Dragon Mail"], "AtlasLootCrafting" },
	--ZG Sets
	["ZGDruid"] = { BC["Druid"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGHunter"] = { BC["Hunter"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGMage"] = { BC["Mage"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGPaladin"] = { BC["Paladin"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGPriest"] = { BC["Priest"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGRogue"] = { BC["Rogue"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGShaman"] = { BC["Shaman"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGWarlock"] = { BC["Warlock"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	["ZGWarrior"] = { BC["Warrior"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	--AQ20 Sets
	["AQ20Mage"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Warlock"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Priest"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Rogue"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Druid"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Hunter"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Paladin"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Shaman"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	["AQ20Warrior"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	--AQ40 Sets
	["AQ40Mage"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Priest"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Warlock"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Rogue"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Druid"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Shaman"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Hunter"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Warrior"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	["AQ40Paladin"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	--Dungeon Set 1/2
	["T0Druid"] = { BC["Druid"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Hunter"] = { BC["Hunter"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Mage"] = { BC["Mage"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Paladin"] = { BC["Paladin"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Priest"] = { BC["Priest"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Rogue"] = { BC["Rogue"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Shaman"] = { BC["Shaman"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Warlock"] = { BC["Warlock"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	["T0Warrior"] = { BC["Warrior"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	--T1Sets
	["T1Druid"] = { BC["Druid"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Hunter"] = { BC["Hunter"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Mage"] = { BC["Mage"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Paladin"] = { BC["Paladin"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Priest"] = { BC["Priest"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Rogue"] = { BC["Rogue"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Shaman"] = { BC["Shaman"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Warlock"] = { BC["Warlock"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	["T1Warrior"] = { BC["Warrior"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	--T2Sets
	["T2Druid"] = { BC["Druid"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Hunter"] = { BC["Hunter"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Mage"] = { BC["Mage"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Paladin"] = { BC["Paladin"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Priest"] = { BC["Priest"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Rogue"] = { BC["Rogue"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Shaman"] = { BC["Shaman"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Warlock"] = { BC["Warlock"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	["T2Warrior"] = { BC["Warrior"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	--T3 Sets
	["T3Druid"] = { BC["Druid"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Hunter"] = { BC["Hunter"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Mage"] = { BC["Mage"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Paladin"] = { BC["Paladin"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Priest"] = { BC["Priest"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Rogue"] = { BC["Rogue"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Shaman"] = { BC["Shaman"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Warlock"] = { BC["Warlock"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	["T3Warrior"] = { BC["Warrior"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	
	------------------------
	--- Misc Collections ---
	------------------------
	
	["CraftedWeapons1"] = { AL["Crafted Epic Weapons"], "AtlasLootCrafting" },
	["WorldEpics1"] = { AL["World Epics"].." - "..AL["Level 30-39"], "AtlasLootSetItems" },
	["WorldEpics2"] = { AL["World Epics"].." - "..AL["Level 40-49"], "AtlasLootSetItems" },
	["WorldEpics3"] = { AL["World Epics"].." - "..AL["Level 50-60"], "AtlasLootSetItems" },
	
	--------------------
	--- World Bosses ---
	--------------------
	
	--Azuregos
	["AAzuregos"] = { BB["Azuregos"], "AtlasLootWBItems" },
	["ASpiritA"] = { AL["Spirit of Azuregos"], "AtlasLootWBItems" },
	--Doom Lord Kazzak
	["KKazzak"] = { BB["Lord Kazzak"], "AtlasLootWBItems" },
	--Emrald Dragons
	["DEmeriss"] = { BB["Emeriss"], "AtlasLootWBItems" },
	["DLethon"] = { BB["Lethon"], "AtlasLootWBItems" },
	["DTaerar"] = { BB["Taerar"], "AtlasLootWBItems" },
	["DYsondre"] = { BB["Ysondre"], "AtlasLootWBItems" },
	["DTrash"] = { AL["Trash Mobs"].." ("..AL["Emerald Dragons"]..")", "AtlasLootWBItems" },
	
	--------------
	--- Events ---
	--------------
	
	--Abyssal Council
	["AbyssalTemplars"] = { "Abyssal Council - Templars", "AtlasLootWorldEvents" },
	["AbyssalDukes"] = { "Abyssal Council - Dukes", "AtlasLootWorldEvents" },
	["AbyssalLords"] = { "Abyssal Council - High Council", "AtlasLootWorldEvents" },
	--Seasonal
	["ChildrensWeek"] = { AL["Children's Week"], "AtlasLootWorldEvents" },
	["Halloween1"] = { AL["Hallow's End"], "AtlasLootWorldEvents" },
	["Halloween2"] = { AL["Hallow's End"], "AtlasLootWorldEvents" },
	["HarvestFestival"] = { AL["Harvest Festival"], "AtlasLootWorldEvents" },
	["LunarFestival1"] = { AL["Lunar Festival"], "AtlasLootWorldEvents" },
	["LunarFestival2"] = { AL["Lunar Festival"], "AtlasLootWorldEvents" },
	["MidsummerFestival"] = { AL["Midsummer Fire Festival"], "AtlasLootWorldEvents" },
	["Noblegarden"] = { AL["Noblegarden"], "AtlasLootWorldEvents" },
	["Valentineday"] = { AL["Love is in the Air"], "AtlasLootWorldEvents" },
	["Winterviel1"] = { AL["Feast of Winter Veil"], "AtlasLootWorldEvents" },
	["Winterviel2"] = { AL["Feast of Winter Veil"], "AtlasLootWorldEvents" },
	--Other
	["ElementalInvasion"] = { AL["Elemental Invasion"], "AtlasLootWorldEvents" },
	["FishingExtravaganza"] = { AL["Stranglethorn Fishing Extravaganza"], "AtlasLootWorldEvents" },
	["GurubashiArena"] = { AL["Gurubashi Arena Booty Run"], "AtlasLootWorldEvents" },
	["ScourgeInvasionEvent1"] = { AL["Scourge Invasion"], "AtlasLootWorldEvents" },
	["ScourgeInvasionEvent2"] = { AL["Scourge Invasion Bosses"], "AtlasLootWorldEvents" },
	
	------------------------
	--- Classic Factions ---
	------------------------
	
	--Argent Dawn
	["Argent1"] = { BF["Argent Dawn"]..": Token Hand-ins", "AtlasLootRepItems" },
	["Argent2"] = { BF["Argent Dawn"], "AtlasLootRepItems" },
	["Argent3"] = { BF["Argent Dawn"], "AtlasLootRepItems" },
	--Bloodsail Buccaneers
	["Bloodsail1"] = { BF["Bloodsail Buccaneers"], "AtlasLootRepItems" },
	--Brood of Nozdormu
	["AQBroodRings"] = { BF["Brood of Nozdormu"], "AtlasLootRepItems" },
	--Cenarion Circle
	["Cenarion1"] = { BF["Cenarion Circle"]..": "..BF["Friendly"], "AtlasLootRepItems" },
	["Cenarion2"] = { BF["Cenarion Circle"]..": "..BF["Honored"], "AtlasLootRepItems" },
	["Cenarion3"] = { BF["Cenarion Circle"]..": "..BF["Revered"], "AtlasLootRepItems" },
	["Cenarion4"] = { BF["Cenarion Circle"]..": "..BF["Exalted"], "AtlasLootRepItems" },
	--The Darkmoon Faire
	["Darkmoon"] = { BF["Darkmoon Faire"], "AtlasLootRepItems" },
	--The Defilers
	["Defilers"] = { BF["The Defilers"], "AtlasLootRepItems" },
	--Frostwolf Clan
	["Frostwolf1"] = { BF["Frostwolf Clan"], "AtlasLootRepItems" },
	--Hydraxian Waterlords
	["WaterLords1"] = { BF["Hydraxian Waterlords"], "AtlasLootRepItems" },
	--Gelkis Clan Centaur
	["GelkisClan1"] = { BF["Gelkis Clan Centaur"], "AtlasLootRepItems" },
	--The League of Arathor
	["LeagueofArathor"] = { BF["The League of Arathor"], "AtlasLootRepItems" },
	--Magram Clan Centaur
	["MagramClan1"] = { BF["Magram Clan Centaur"], "AtlasLootRepItems" },
	--Stormpike Guard
	["Stormpike1"] = { BF["Stormpike Guard"], "AtlasLootRepItems" },
	--Thorium Brotherhood
	["Thorium1"] = { BF["Thorium Brotherhood"]..": "..BF["Friendly"].."/"..BF["Honored"], "AtlasLootRepItems" },
	["Thorium2"] = { BF["Thorium Brotherhood"]..": "..BF["Revered"].."/"..BF["Exalted"], "AtlasLootRepItems" },
	--Timbermaw Hold
	["Timbermaw"] = { BF["Timbermaw Hold"], "AtlasLootRepItems" },
	--Wintersaber Trainers
	["Wintersaber1"] = { BF["Wintersaber Trainers"], "AtlasLootRepItems" },
	--Zandalar Tribe
	["Zandalar1"] = { BF["Zandalar Tribe"]..": "..BF["Friendly"].."/"..BF["Honored"], "AtlasLootRepItems" },
	["Zandalar2"] = { BF["Zandalar Tribe"]..": "..BF["Revered"].."/"..BF["Exalted"], "AtlasLootRepItems" },
	
	--------------
	--- Trades ---
	--------------
	
	--Alchemy
	["AlchemyApprentice1"] = { BS["Alchemy"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
	["AlchemyJourneyman1"] = { BS["Alchemy"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["AlchemyExpert1"] = { BS["Alchemy"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["AlchemyArtisan1"] = { BS["Alchemy"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["AlchemyArtisan2"] = { BS["Alchemy"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	--BlackSmithing
	["SmithingApprentice1"] = { BS["Blacksmithing"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
	["SmithingJourneyman1"] = { BS["Blacksmithing"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["SmithingJourneyman2"] = { BS["Blacksmithing"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["SmithingExpert1"] = { BS["Blacksmithing"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["SmithingExpert2"] = { BS["Blacksmithing"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["SmithingArtisan1"] = { BS["Blacksmithing"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["SmithingArtisan2"] = { BS["Blacksmithing"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["SmithingArtisan3"] = { BS["Blacksmithing"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["Armorsmith1"] = { BS["Armorsmith"], "AtlasLootCrafting" },
	["Weaponsmith1"] = { BS["Weaponsmith"], "AtlasLootCrafting" },
	["Axesmith1"] = { AL["Master Axesmith"], "AtlasLootCrafting" },
	["Hammersmith1"] = {BS["Blacksmithing"]..": ".. AL["Master Hammersmith"], "AtlasLootCrafting" },
	["Swordsmith1"] = { AL["Master Swordsmith"], "AtlasLootCrafting" },
	--Enchanting
	["EnchantingApprentice1"] = { BS["Enchanting"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
	["EnchantingJourneyman1"] = { BS["Enchanting"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["EnchantingJourneyman2"] = { BS["Enchanting"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["EnchantingExpert1"] = { BS["Enchanting"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["EnchantingExpert2"] = { BS["Enchanting"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["EnchantingArtisan1"] = { BS["Enchanting"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["EnchantingArtisan2"] = { BS["Enchanting"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["EnchantingArtisan3"] = { BS["Enchanting"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	--Engineering
	["EngineeringApprentice1"] = { BS["Engineering"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
	["EngineeringJourneyman1"] = { BS["Engineering"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["EngineeringJourneyman2"] = { BS["Engineering"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["EngineeringExpert1"] = { BS["Engineering"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["EngineeringExpert2"] = { BS["Engineering"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["EngineeringArtisan1"] = { BS["Engineering"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["EngineeringArtisan2"] = { BS["Engineering"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["Gnomish1"] = { AL["Gnomish Engineering"], "AtlasLootCrafting" },
	["Goblin1"] = { AL["Goblin Engineering"], "AtlasLootCrafting" },
	--Leatherworking
	["LeatherApprentice1"] = { BS["Leatherworking"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
	["LeatherJourneyman1"] = { BS["Leatherworking"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["LeatherJourneyman2"] = { BS["Leatherworking"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["LeatherExpert1"] = { BS["Leatherworking"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["LeatherExpert2"] = { BS["Leatherworking"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["LeatherArtisan1"] = { BS["Leatherworking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["LeatherArtisan2"] = { BS["Leatherworking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["LeatherArtisan3"] = { BS["Leatherworking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["Dragonscale1"] = { BS["Dragonscale Leatherworking"], "AtlasLootCrafting" },
	["Elemental1"] = { BS["Elemental Leatherworking"], "AtlasLootCrafting" },
	["Tribal1"] = { BS["Tribal Leatherworking"], "AtlasLootCrafting" },
	--Mining
	["Mining1"] = { BS["Mining"], "AtlasLootCrafting" },
	["Mining2"] = { BS["Mining"], "AtlasLootCrafting" },
	["Smelting1"] = { BS["Smelting"], "AtlasLootCrafting" },
	["Herbalism1"] = { BS["Herbalism"], "AtlasLootCrafting" },
	["Herbalism2"] = { BS["Herbalism"], "AtlasLootCrafting" },
	--Tailoring
	["TailoringApprentice1"] = { BS["Tailoring"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
	["TailoringJourneyman1"] = { BS["Tailoring"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["TailoringJourneyman2"] = { BS["Tailoring"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["TailoringExpert1"] = { BS["Tailoring"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["TailoringExpert2"] = { BS["Tailoring"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["TailoringArtisan1"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["TailoringArtisan2"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["TailoringArtisan3"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	["TailoringArtisan4"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	--Cooking
	["CookingApprentice1"] = { BS["Cooking"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
	["CookingJourneyman1"] = { BS["Cooking"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
	["CookingExpert1"] = { BS["Cooking"]..": "..AL["Expert"], "AtlasLootCrafting" },
	["CookingArtisan1"] = { BS["Cooking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
	--FirstAid
	["FirstAid1"] = { BS["First Aid"], "AtlasLootCrafting" },
	--Poisons
	["Poisons1"] = { BC["Rogue"]..": "..BS["Poisons"], "AtlasLootCrafting" },
	
	-----------
	--- PvP ---
	-----------
	
	--Battlegrounds
 	--Alterac Valley
	["AVRepFriendly"] = { BZ["Alterac Valley"].." 51-60 "..AL["Friendly Rewards"], "AtlasLootBGItems" },
	["AVRepHonored"] = { BZ["Alterac Valley"].." 51-60 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["AVRepRevered"] = { BZ["Alterac Valley"].." 51-60 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["AVRepExalted"] = { BZ["Alterac Valley"].." 51-60 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
 	--Arathi Basin
	["ABRepFriendly"] = { BZ["Arathi Basin"].." Friendly Rewards", "AtlasLootBGItems" },
	["ABRepHonored2029"] = { BZ["Arathi Basin"].." 20-29 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["ABRepHonored3039"] = { BZ["Arathi Basin"].." 30-39 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["ABRepHonored4049"] = { BZ["Arathi Basin"].." 40-49 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["ABRepHonored5059"] = { BZ["Arathi Basin"].." 50-59 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["ABRepRevered2029"] = { BZ["Arathi Basin"].." 20-29 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["ABRepRevered3039"] = { BZ["Arathi Basin"].." 30-39 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["ABRepRevered4049"] = { BZ["Arathi Basin"].." 40-49 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["ABRepRevered5059"] = { BZ["Arathi Basin"].." 50-59 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["ABRepExalted"] = { BZ["Arathi Basin"].." 60 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
 	--Warsong Gulch
	["WSGRepFriendly"] = { BZ["Warsong Gulch"].." "..AL["Friendly Rewards"], "AtlasLootBGItems" },
	["WSGRepHonored1019"] = { BZ["Warsong Gulch"].." 10-19 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["WSGRepHonored2029"] = { BZ["Warsong Gulch"].." 20-29 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["WSGRepHonored3039"] = { BZ["Warsong Gulch"].." 30-39 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["WSGRepHonored4049"] = { BZ["Warsong Gulch"].." 40-49 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["WSGRepHonored5059"] = { BZ["Warsong Gulch"].." 50-59 "..AL["Honored Rewards"], "AtlasLootBGItems" },
	["WSGRepRevered1019"] = { BZ["Warsong Gulch"].." 10-19 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["WSGRepRevered2029"] = { BZ["Warsong Gulch"].." 20-29 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["WSGRepRevered3039"] = { BZ["Warsong Gulch"].." 30-39 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["WSGRepRevered4049"] = { BZ["Warsong Gulch"].." 40-49 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["WSGRepRevered5059"] = { BZ["Warsong Gulch"].." 50-59 "..AL["Revered Rewards"], "AtlasLootBGItems" },
	["WSGRepExalted4049"] = { BZ["Warsong Gulch"].." 40-49 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
	["WSGRepExalted5059"] = { BZ["Warsong Gulch"].." 50-59 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
	["WSGRepExalted60"] = { BZ["Warsong Gulch"].." 60 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
	--Misc Other PvP
	["PvP60Accessories1"] = { AL["PvP Accessories"], "AtlasLootGeneralPvPItems" },
	["PvP60Accessories2"] = { AL["PvP Accessories - Alliance"], "AtlasLootGeneralPvPItems" },
	["PvP60Accessories3"] = { AL["PvP Accessories - Horde"], "AtlasLootGeneralPvPItems" },
	["PVPWeapons1"] = { AL["Rank 14 Weapons"], "AtlasLootGeneralPvPItems" },
	["PVPWeapons2"] = { AL["Rank 14 Weapons"], "AtlasLootGeneralPvPItems" },
	["PvPMountsPvP"] = { AL["PvP Mounts"], "AtlasLootGeneralPvPItems" },
	--Level 60 PvP Sets
	["PVPDruid"] = { BC["Druid"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPHunter"] = { BC["Hunter"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPMage"] = { BC["Mage"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPPaladin"] = { BC["Paladin"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPPriest"] = { BC["Priest"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPRogue"] = { BC["Rogue"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPShaman"] = { BC["Shaman"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPWarlock"] = { BC["Warlock"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	["PVPWarrior"] = { BC["Warrior"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	
	-------------
	--- Other ---
	-------------
	
	--Menus, the entry does nothing, but makes the generalised loot table code less complex
	["PVPMENU"] = { "dummy", "dummy" },
	["PVPSET"] = { "dummy", "dummy" },
	["AVRepMenu"] = { "dummy", "dummy" },
	["ABRepMenu"] = { "dummy", "dummy" },
	["WSGRepMenu"] = { "dummy", "dummy" },
	["AQ40SET"] = { "dummy", "dummy" },
	["AQ20SET"] = { "dummy", "dummy" },
	["ZGSET"] = { "dummy", "dummy" },
	["PRE60SET"] = { "dummy", "dummy" },
	["T3SET"] = { "dummy", "dummy" },
	["T2SET"] = { "dummy", "dummy" },
	["T1SET"] = { "dummy", "dummy" },
	["T0SET"] = { "dummy", "dummy" },
	["REPMENU"] = { "dummy", "dummy" },
	["SETMENU"] = { "dummy", "dummy" },
	["WORLDEPICS"] = { "dummy", "dummy" },
	["WORLDEVENTMENU"] = { "dummy", "dummy" },
	["AbyssalCouncil"] = { "dummy", "dummy" },
	["ALCHEMYMENU"] = { "dummy", "dummy" },
	["CRAFTSET"] = { "dummy", "dummy" },
	["HONORMENU"] = { "dummy", "dummy" },
	["CRAFTINGMENU"] = { "dummy", "dummy" },
	["SMITHINGMENU"] = { "dummy", "dummy" },
	["ENCHANTINGMENU"] = { "dummy", "dummy" },
	["ENGINEERINGMENU"] = { "dummy", "dummy" },
	["LEATHERWORKINGMENU"] = { "dummy", "dummy" },
	["MININGMENU"] = { "dummy", "dummy" },
	["TAILORINGMENU"] = { "dummy", "dummy" },
	["COOKINGMENU"] = { "dummy", "dummy" },
	["FIRSTAIDMENU"] = { "dummy", "dummy" },
	["WishList"] = { AL["WishList"], "AtlasLootCharDB" },
	--If all else fails!
	["EmptyInstance"] = { "AtlasLoot", "AtlasLootFallback" },
};

AtlasLoot_TableNamesBoss = {
	
	[AL["Keys"]] = {
		["VanillaKeys"] = { AL["Keys"], "AtlasLootItems" },
	},
	[BZ["Blackfathom Deeps"]] = {
		["BFDGhamoora"] = { BB["Ghamoo-ra"], "AtlasLootItems" },
		["BFDLadySarevess"] = { BB["Lady Sarevess"], "AtlasLootItems" },
		["BFDGelihast"] = { BB["Gelihast"], "AtlasLootItems" },
		["BFDBaronAquanis"] = { BB["Baron Aquanis"], "AtlasLootItems" },
		["BFDTwilightLordKelris"] = { BB["Twilight Lord Kelris"], "AtlasLootItems" },
		["BFDOldSerrakis"] = { BB["Old Serra'kis"], "AtlasLootItems" },
		["BFDAkumai"] = { BB["Aku'mai"], "AtlasLootItems" },
		["BFDTrash"] = { AL["Trash Mobs"].." ("..BZ["Blackfathom Deeps"]..")", "AtlasLootItems" },
	},
	[BZ["Blackrock Mountain"]] = {
		["BRMScarshieldQuartermaster"] = { AL["Scarshield Quartermaster"], "AtlasLootItems" },
		["BRDPyron"] = { AL["Overmaster Pyron"], "AtlasLootItems" },
	},
	[BZ["Blackrock Depths"]] = {
		["BRDLordRoccor"] = { BB["Lord Roccor"], "AtlasLootItems" },
		["BRDHighInterrogatorGerstahn"] = { BB["High Interrogator Gerstahn"], "AtlasLootItems" },
		["BRDAnubshiah"] = { BB["Anub'shiah"], "AtlasLootItems" },
		["BRDEviscerator"] = { BB["Eviscerator"], "AtlasLootItems" },
		["BRDGorosh"] = { BB["Gorosh the Dervish"], "AtlasLootItems" },
		["BRDGrizzle"] = { BB["Grizzle"], "AtlasLootItems" },
		["BRDHedrum"] = { BB["Hedrum the Creeper"], "AtlasLootItems" },
		["BRDOkthor"] = { BB["Ok'thor the Breaker"], "AtlasLootItems" },
		["BRDTheldren"] = { AL["Theldren"], "AtlasLootItems" },
		["BRDHoundmaster"] = { BB["Houndmaster Grebmar"], "AtlasLootItems" },
		["BRDForgewright"] = { AL["Monument of Franclorn Forgewright"], "AtlasLootItems" },
		["BRDPyromancerLoregrain"] = { BB["Pyromancer Loregrain"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["BRDTheVault"] = { AL["The Vault"], "AtlasLootItems" },
		["BRDWarderStilgiss"] = { BB["Warder Stilgiss"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["BRDVerek"] = { BB["Verek"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["BRDFineousDarkvire"] = { BB["Fineous Darkvire"], "AtlasLootItems" },
		["BRDLordIncendius"] = { BB["Lord Incendius"], "AtlasLootItems" },
		["BRDBaelGar"] = { BB["Bael'Gar"], "AtlasLootItems" },
		["BRDGeneralAngerforge"] = { BB["General Angerforge"], "AtlasLootItems" },
		["BRDGolemLordArgelmach"] = { BB["Golem Lord Argelmach"], "AtlasLootItems" },
		["BRDGuzzler"] = { AL["The Grim Guzzler"], "AtlasLootItems" },
		["BRDFlamelash"] = { BB["Ambassador Flamelash"], "AtlasLootItems" },
		["BRDPanzor"] = { BB["Panzor the Invincible"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["BRDTomb"] = { "Summoner's Tomb", "AtlasLootItems" },
		["BRDLyceum"] = { AL["Shadowforge Flame Keeper"], "AtlasLootItems" },
		["BRDMagmus"] = { BB["Magmus"], "AtlasLootItems" },
		["BRDPrincess"] = { BB["Princess Moira Bronzebeard"], "AtlasLootItems" },
		["BRDEmperorDagranThaurissan"] = { BB["Emperor Dagran Thaurissan"], "AtlasLootItems" },
		["BRDBSPlans"] = { "Blacksmith Plans".." ("..BZ["Blackrock Depths"]..")", "AtlasLootItems" },
		["BRDTrash"] = { AL["Trash Mobs"].." ("..BZ["Blackrock Depths"]..")", "AtlasLootItems" },
	},
	[BZ["Lower Blackrock Spire"]] = {
		["LBRSSpirestoneButcher"] = { AL["Spirestone Butcher"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["LBRSPike"] = { AL["Roughshod Pike"], "AtlasLootItems" },
		["LBRSOmokk"] = { BB["Highlord Omokk"], "AtlasLootItems" },
		["LBRSSpirestoneBattleLord"] = { AL["Spirestone Battle Lord"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["LBRSSpirestoneLordMagus"] = { AL["Spirestone Lord Magus"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["LBRSVosh"] = { BB["Shadow Hunter Vosh'gajin"], "AtlasLootItems" },
		["LBRSVoone"] = { BB["War Master Voone"], "AtlasLootItems" },
		["LBRSGrayhoof"] = { BB["Mor Grayhoof"].." ("..AL["Summon"]..")", "AtlasLootItems" },
		["LBRSGrimaxe"] = { BB["Bannok Grimaxe"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["LBRSSmolderweb"] = { BB["Mother Smolderweb"], "AtlasLootItems" },
		["LBRSCrystalFang"] = { BB["Crystal Fang"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["LBRSHumanRemains"] = { AL["Human Remains"], "AtlasLootItems" },
		["LBRSDoomhowl"] = { BB["Urok Doomhowl"].." ("..AL["Summon"]..")", "AtlasLootItems" },
		["LBRSZigris"] = { BB["Quartermaster Zigris"], "AtlasLootItems" },
		["LBRSHalycon"] = { BB["Halycon"], "AtlasLootItems" },
		["LBRSSlavener"] = { BB["Gizrul the Slavener"], "AtlasLootItems" },
		["LBRSBashguud"] = { BB["Ghok Bashguud"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["LBRSWyrmthalak"] = { BB["Overlord Wyrmthalak"], "AtlasLootItems" },
		["LBRSFelguard"] = { AL["Burning Felguard"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["LBRSTrash"] = { AL["Trash Mobs"].." ("..BZ["Lower Blackrock Spire"]..")", "AtlasLootItems" },
	},
	[BZ["Upper Blackrock Spire"]] = {
		["UBRSEmberseer"] = { BB["Pyroguard Emberseer"], "AtlasLootItems" },
		["UBRSSolakar"] = { BB["Solakar Flamewreath"], "AtlasLootItems" },
		["UBRSFlame"] = { AL["Father Flame"], "AtlasLootItems" },
		["UBRSRunewatcher"] = { BB["Jed Runewatcher"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["UBRSAnvilcrack"] = { BB["Goraluk Anvilcrack"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["UBRSRend"] = { BB["Warchief Rend Blackhand"], "AtlasLootItems" },
		["UBRSGyth"] = { BB["Gyth"], "AtlasLootItems" },
		["UBRSBeast"] = { BB["The Beast"], "AtlasLootItems" },
		["UBRSValthalak"] = { BB["Lord Valthalak"].." ("..AL["Summon"]..")", "AtlasLootItems" },
		["UBRSDrakkisath"] = { BB["General Drakkisath"], "AtlasLootItems" },
		["UBRSTrash"] = { AL["Trash Mobs"].." ("..BZ["Upper Blackrock Spire"]..")", "AtlasLootItems" },
	},
	[BZ["Blackwing Lair"]] = {
		["BWLRazorgore"] = { BB["Razorgore the Untamed"], "AtlasLootItems" },
		["BWLVaelastrasz"] = { BB["Vaelastrasz the Corrupt"], "AtlasLootItems" },
		["BWLLashlayer"] = { BB["Broodlord Lashlayer"], "AtlasLootItems" },
		["BWLFiremaw"] = { BB["Firemaw"], "AtlasLootItems" },
		["BWLEbonroc"] = { BB["Ebonroc"], "AtlasLootItems" },
		["BWLFlamegor"] = { BB["Flamegor"], "AtlasLootItems" },
		["BWLChromaggus"] = { BB["Chromaggus"], "AtlasLootItems" },
		["BWLNefarian"] = { BB["Nefarian"], "AtlasLootItems" },
		["BWLTrashMobs"] = { AL["Trash Mobs"].." ("..BZ["Blackwing Lair"]..")", "AtlasLootItems" },
	},
	["The Deadmines Entrance"] = {
		["DMMarisaduPaige"] = { AL["Marisa du'Paige"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["DMBrainwashedNoble"] = { AL["Brainwashed Noble"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["DMForemanThistlenettle"] = { AL["Foreman Thistlenettle"], "AtlasLootItems" },
	},
	[BZ["The Deadmines"]] = {
		["DMRhahkZor"] = { BB["Rhahk'Zor"], "AtlasLootItems" },
		["DMMinerJohnson"] = { BB["Miner Johnson"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["DMSneed"] = { BB["Sneed"], "AtlasLootItems" },
		["DMSneedsShredder"] = { AL["Sneed's Shredder"], "AtlasLootItems" },
		["DMGilnid"] = { BB["Gilnid"], "AtlasLootItems" },
		["DMDefiasGunpowder"] = { AL["Defias Gunpowder"], "AtlasLootItems" },
		["DMMrSmite"] = { BB["Mr. Smite"], "AtlasLootItems" },
		["DMCookie"] = { BB["Cookie"], "AtlasLootItems" },
		["DMCaptainGreenskin"] = { BB["Captain Greenskin"], "AtlasLootItems" },
		["DMVanCleef"] = { BB["Edwin VanCleef"], "AtlasLootItems" },
		["DMTrash"] = { AL["Trash Mobs"].." ("..BZ["The Deadmines"]..")", "AtlasLootItems" },
	},
	[BZ["Dire Maul (East)"]] = {
		["DMEPusillin"] = { BB["Pusillin"], "AtlasLootItems" },
		["DMEZevrimThornhoof"] = { BB["Zevrim Thornhoof"], "AtlasLootItems" },
		["DMEHydro"] = { BB["Hydrospawn"], "AtlasLootItems" },
		["DMELethtendris"] = { BB["Lethtendris"], "AtlasLootItems" },
		["DMEPimgib"] = { BB["Pimgib"], "AtlasLootItems" },
		["DMEAlzzin"] = { BB["Alzzin the Wildshaper"], "AtlasLootItems" },
		["DMEIsalien"] = { BB["Isalien"], "AtlasLootItems" },
		["DMETrash"] = { AL["Trash Mobs"].." ("..BZ["Dire Maul (East)"]..")", "AtlasLootItems" },
		["DMEShard"] = { AL["Felvine Shard"], "AtlasLootItems" },
		["DMTome"] = { AL["A Dusty Tome"], "AtlasLootItems" },
		["DMBooks"] = { "Dire Maul Books", "AtlasLootItems" },
	},
	[BZ["Dire Maul (North)"]] = {
		["DMNGuardMoldar"] = { BB["Guard Mol'dar"], "AtlasLootItems" },
		["DMNStomperKreeg"] = { AL["Stomper Kreeg"], "AtlasLootItems" },
		["DMNGuardFengus"] = { BB["Guard Fengus"], "AtlasLootItems" },
		["DMNThimblejack"] = { AL["Knot Thimblejack"], "AtlasLootItems" },
		["DMNGuardSlipkik"] = { BB["Guard Slip'kik"], "AtlasLootItems" },
		["DMNCaptainKromcrush"] = { BB["Captain Kromcrush"], "AtlasLootItems" },
		["DMNChoRush"] = { BB["Cho'Rush the Observer"], "AtlasLootItems" },
		["DMNKingGordok"] = { BB["King Gordok"], "AtlasLootItems" },
		["DMNTrash"] = { AL["Trash Mobs"].." ("..BZ["Dire Maul (North)"]..")", "AtlasLootItems" },
		["DMNTRIBUTERUN"] = { AL["Tribute Chest"], "AtlasLootItems" },
	},
	[BZ["Dire Maul (West)"]] = {
		["DMWTendrisWarpwood"] = { BB["Tendris Warpwood"], "AtlasLootItems" },
		["DMWIllyannaRavenoak"] = { BB["Illyanna Ravenoak"], "AtlasLootItems" },
		["DMWMagisterKalendris"] = { BB["Magister Kalendris"], "AtlasLootItems" },
		["DMWTsuzee"] = { BB["Tsu'zee"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["DMWRevanchion"] = { BB["Revanchion"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
		["DMWImmolthar"] = { BB["Immol'thar"], "AtlasLootItems" },
		["DMWHelnurath"] = { BB["Lord Hel'nurath"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["DMWPrinceTortheldrin"] = { BB["Prince Tortheldrin"], "AtlasLootItems" },
		["DMWShendralarProvisioner"] = { AL["Shen'dralar Provisioner"], "AtlasLootItems" },
		["DMWTrash"] = { AL["Trash Mobs"].." ("..BZ["Dire Maul (West)"]..")", "AtlasLootItems" },
	},
	[BZ["Gnomeregan"].." ("..AL["Entrance"]..")"] = {
		["GnNamdoBizzfizzle"] = { AL["Namdo Bizzfizzle"], "AtlasLootItems" },
		["GnTechbot"] = { AL["Techbot"], "AtlasLootItems" },
		["GnPunchographA"] = { AL["Matrix Punchograph 3005-A"], "AtlasLootItems" },
		["GnOutsideTrash"] = { AL["Trash Mobs"].." ("..BZ["Gnomeregan"].." "..AL["Entrance"]..")", "AtlasLootItems" },
	},
	[BZ["Gnomeregan"]] = {
		["GnGrubbis"] = { BB["Grubbis"], "AtlasLootItems" },
		["GnViscousFallout"] = { BB["Viscous Fallout"], "AtlasLootItems" },
		["GnElectrocutioner6000"] = { BB["Electrocutioner 6000"], "AtlasLootItems" },
		["GnCrowdPummeler960"] = { BB["Crowd Pummeler 9-60"], "AtlasLootItems" },
		["GnDIAmbassador"] = { BB["Dark Iron Ambassador"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["GnMekgineerThermaplugg"] = { BB["Mekgineer Thermaplugg"], "AtlasLootItems" },
		["GnTrash"] = { AL["Trash Mobs"].." ("..BZ["Gnomeregan"]..")", "AtlasLootItems" },
		["GnPunchographB"] = { AL["Matrix Punchograph 3005-B"], "AtlasLootItems" },
		["GnPunchographC"] = { AL["Matrix Punchograph 3005-C"], "AtlasLootItems" },
		["GnPunchographD"] = { AL["Matrix Punchograph 3005-D"], "AtlasLootItems" },
	},
	[BZ["Maraudon"].." ("..AL["Entrance"]..")"] = {
		["MaraNamelesProphet"] = { AL["The Nameles Prophet"], "AtlasLootItems" },
		["MaraKhanKolk"] = { AL["Kolk"].." (The First Khan)", "AtlasLootItems" },
		["MaraKhanGelk"] = { AL["Gelk"].." (The Second Khan)", "AtlasLootItems" },
		["MaraKhanMagra"] = { AL["Magra"].." (The Third Khan)", "AtlasLootItems" },
	},
	[BZ["Maraudon"]] = {
		["MaraKhanVeng"] = { AL["Veng"].." (The Fifth Khan)", "AtlasLootItems" },
		["MaraNoxxion"] = { BB["Noxxion"], "AtlasLootItems" },
		["MaraRazorlash"] = { BB["Razorlash"], "AtlasLootItems" },
		["MaraKhanMaraudos"] = { AL["Maraudos"].." (The Forth Khan)", "AtlasLootItems" },
		["MaraLordVyletongue"] = { BB["Lord Vyletongue"], "AtlasLootItems" },
		["MaraMeshlok"] = { BB["Meshlok the Harvester"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["MaraCelebras"] = { BB["Celebras the Cursed"], "AtlasLootItems" },
		["MaraLandslide"] = { BB["Landslide"], "AtlasLootItems" },
		["MaraTinkererGizlock"] = { BB["Tinkerer Gizlock"], "AtlasLootItems" },
		["MaraRotgrip"] = { BB["Rotgrip"], "AtlasLootItems" },
		["MaraPrincessTheradras"] = { BB["Princess Theradras"], "AtlasLootItems" },
	},
	[BZ["Molten Core"]] = {
		["MCLucifron"] = { BB["Lucifron"], "AtlasLootItems" },
		["MCMagmadar"] = { BB["Magmadar"], "AtlasLootItems" },
		["MCGehennas"] = { BB["Gehennas"], "AtlasLootItems" },
		["MCGarr"] = { BB["Garr"], "AtlasLootItems" },
		["MCShazzrah"] = { BB["Shazzrah"], "AtlasLootItems" },
		["MCGeddon"] = { BB["Baron Geddon"], "AtlasLootItems" },
		["MCGolemagg"] = { BB["Golemagg the Incinerator"], "AtlasLootItems" },
		["MCSulfuron"] = { BB["Sulfuron Harbinger"], "AtlasLootItems" },
		["MCMajordomo"] = { BB["Majordomo Executus"], "AtlasLootItems" },
		["MCRagnaros"] = { BB["Ragnaros"], "AtlasLootItems" },
		["MCRANDOMBOSSDROPS"] = { "Random Boss Drops", "AtlasLootItems" },
		["MCTrashMobs"] = { AL["Trash Mobs"].." ("..BZ["Molten Core"]..")", "AtlasLootItems" },
	},
	[BZ["Naxxramas"]] = {
		["NAXPatchwerk"] = { BB["Patchwerk"], "AtlasLootItems" },
		["NAXGrobbulus"] = { BB["Grobbulus"], "AtlasLootItems" },
		["NAXGluth"] = { BB["Gluth"], "AtlasLootItems" },
		["NAXThaddius"] = { BB["Thaddius"], "AtlasLootItems" },
		["NAXAnubRekhan"] = { BB["Anub'Rekhan"], "AtlasLootItems" },
		["NAXGrandWidowFaerlina"] = { BB["Grand Widow Faerlina"], "AtlasLootItems" },
		["NAXMaexxna"] = { BB["Maexxna"], "AtlasLootItems" },
		["NAXInstructorRazuvious"] = { BB["Instructor Razuvious"], "AtlasLootItems" },
		["NAXGothiktheHarvester"] = { BB["Gothik the Harvester"], "AtlasLootItems" },
		["NAXTheFourHorsemen"] = { BB["The Four Horsemen"], "AtlasLootItems" },
		["NAXNoththePlaguebringer"] = { BB["Noth the Plaguebringer"], "AtlasLootItems" },
		["NAXHeigantheUnclean"] = { BB["Heigan the Unclean"], "AtlasLootItems" },
		["NAXLoatheb"] = { BB["Loatheb"], "AtlasLootItems" },
		["NAXSapphiron"] = { BB["Sapphiron"], "AtlasLootItems" },
		["NAXKelThuzard"] = { BB["Kel'Thuzad"], "AtlasLootItems" },
		["NAXTrash"] = { AL["Trash Mobs"].." ("..BZ["Naxxramas"]..")", "AtlasLootItems" },
	},
	[BZ["Onyxia's Lair"]] = {
		["Onyxia"] = { BB["Onyxia"], "AtlasLootItems" },
	},
	[BZ["Ragefire Chasm"]] = {
		["RFCTaragaman"] = { BB["Taragaman the Hungerer"], "AtlasLootItems" },
		["RFCJergosh"] = { BB["Jergosh the Invoker"], "AtlasLootItems" },
	},
	[BZ["Razorfen Downs"]] = {
		["RFDTutenkash"] = { BB["Tuten'kash"], "AtlasLootItems" },
		["RFDHenryStern"] = { AL["Henry Stern"], "AtlasLootItems" },
		["RFDLadyF"] = { BB["Lady Falther'ess"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
		["RFDMordreshFireEye"] = { BB["Mordresh Fire Eye"], "AtlasLootItems" },
		["RFDGlutton"] = { BB["Glutton"], "AtlasLootItems" },
		["RFDRagglesnout"] = { BB["Ragglesnout"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["RFDAmnennar"] = { BB["Amnennar the Coldbringer"], "AtlasLootItems" },
		["RFDPlaguemaw"] = { BB["Plaguemaw the Rotting"], "AtlasLootItems" },
		["RFDTrash"] = { AL["Trash Mobs"].." ("..BZ["Razorfen Downs"]..")", "AtlasLootItems" },
	},
	[BZ["Razorfen Kraul"]] = {
		["RFKAggem"] = { BB["Aggem Thorncurse"], "AtlasLootItems" },
		["RFKDeathSpeakerJargba"] = { BB["Death Speaker Jargba"], "AtlasLootItems" },
		["RFKRazorfenSpearhide"] = { AL["Razorfen Spearhide"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["RFKOverlordRamtusk"] = { BB["Overlord Ramtusk"], "AtlasLootItems" },
		["RFKAgathelos"] = { BB["Agathelos the Raging"], "AtlasLootItems" },
		["RFKBlindHunter"] = { BB["Blind Hunter"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["RFKCharlgaRazorflank"] = { BB["Charlga Razorflank"], "AtlasLootItems" },
		["RFKEarthcallerHalmgar"] = { BB["Earthcaller Halmgar"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["RFKRoogug"] = { BB["Roogug"], "AtlasLootItems" },
		["RFKTrash"] = { AL["Trash Mobs"].." ("..BZ["Razorfen Kraul"]..")", "AtlasLootItems" },
	},
	[BZ["Ruins of Ahn'Qiraj"]] = {
		["AQ20Kurinnaxx"] = { BB["Kurinnaxx"], "AtlasLootItems" },
		["AQ20Andorov"] = { BB["Lieutenant General Andorov"], "AtlasLootItems" },
		["AQ20CAPTAIN"] = { AL["Rajaxx's Captains"], "AtlasLootItems" },
		["AQ20Rajaxx"] = { BB["General Rajaxx"], "AtlasLootItems" },
		["AQ20Moam"] = { BB["Moam"], "AtlasLootItems" },
		["AQ20Buru"] = { BB["Buru the Gorger"], "AtlasLootItems" },
		["AQ20Ayamiss"] = { BB["Ayamiss the Hunter"], "AtlasLootItems" },
		["AQ20Ossirian"] = { BB["Ossirian the Unscarred"], "AtlasLootItems" },
		["AQ20Trash"] = { AL["Trash Mobs"].." (AQ20)", "AtlasLootItems" },
		["AQ20ClassBooks"] = { "AQ Class Books", "AtlasLootItems" },
		["AQEnchants"] = { "AQ Enchants", "AtlasLootItems" },
	},
	[BZ["Scarlet Monastery"]..AL["Armory"]] = {
		["SMHerod"] = { BB["Herod"], "AtlasLootItems" },
		["SMATrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Armory"]..")", "AtlasLootItems" },
	},
	[BZ["Scarlet Monastery"]..AL["Cathedral"]] = {
		["SMFairbanks"] = { BB["High Inquisitor Fairbanks"], "AtlasLootItems" },
		["SMMograine"] = { BB["Scarlet Commander Mograine"], "AtlasLootItems" },
		["SMWhitemane"] = { BB["High Inquisitor Whitemane"], "AtlasLootItems" },
		["SMCTrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Cathedral"]..")", "AtlasLootItems" },
	},
	[BZ["Scarlet Monastery"]..AL["Graveyard"]] = {
		["SMVishas"] = { BB["Interrogator Vishas"], "AtlasLootItems" },
		["SMScorn"] = { BB["Scorn"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
		["SMIronspine"] = { BB["Ironspine"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["SMAzshir"] = { BB["Azshir the Sleepless"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["SMFallenChampion"] = { BB["Fallen Champion"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["SMBloodmageThalnos"] = { BB["Bloodmage Thalnos"], "AtlasLootItems" },
		["SMGTrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Graveyard"]..")", "AtlasLootItems" },
	},
	[BZ["Scarlet Monastery"]..AL["Library"]] = {
		["SMHoundmasterLoksey"] = { BB["Houndmaster Loksey"], "AtlasLootItems" },
		["SMDoan"] = { BB["Arcanist Doan"], "AtlasLootItems" },
		["SMDoansBox"] = { AL["Doan's Strongbox"], "AtlasLootItems" },
		["SMLTrash"] = { AL["Trash Mobs"].." ("..BZ["Scarlet Monastery"].. " "..AL["Library"]..")", "AtlasLootItems" },
	},
	[BZ["Scholomance"]] = {
		["SCHOLOBlood"] = { AL["Blood Steward of Kirtonos"], "AtlasLootItems" },
		["SCHOLOKirtonostheHerald"] = { BB["Kirtonos the Herald"], "AtlasLootItems" },
		["SCHOLOJandiceBarov"] = { BB["Jandice Barov"], "AtlasLootItems" },
		["SCHOLOLordBlackwood"] = { BB["Lord Blackwood"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
		["SCHOLORattlegore"] = { BB["Rattlegore"], "AtlasLootItems" },
		["SCHOLODeathKnight"] = { BB["Death Knight Darkreaver"], "AtlasLootItems" },
		["SCHOLOMarduk"] = { BB["Marduk Blackpool"], "AtlasLootItems" },
		["SCHOLOVectus"] = { BB["Vectus"], "AtlasLootItems" },
		["SCHOLORasFrostwhisper"] = { BB["Ras Frostwhisper"], "AtlasLootItems" },
		["SCHOLOKormok"] = { BB["Kormok"], "AtlasLootItems" },
		["SCHOLOInstructorMalicia"] = { BB["Instructor Malicia"], "AtlasLootItems" },
		["SCHOLODoctorTheolenKrastinov"] = { BB["Doctor Theolen Krastinov"], "AtlasLootItems" },
		["SCHOLOLorekeeperPolkelt"] = { BB["Lorekeeper Polkelt"], "AtlasLootItems" },
		["SCHOLOTheRavenian"] = { BB["The Ravenian"], "AtlasLootItems" },
		["SCHOLOLordAlexeiBarov"] = { BB["Lord Alexei Barov"], "AtlasLootItems" },
		["SCHOLOLadyIlluciaBarov"] = { BB["Lady Illucia Barov"], "AtlasLootItems" },
		["SCHOLODarkmasterGandling"] = { BB["Darkmaster Gandling"], "AtlasLootItems" },
		["SCHOLOTrash"] = { AL["Trash Mobs"].." ("..BZ["Scholomance"]..")", "AtlasLootItems" },
	},
	[BZ["Shadowfang Keep"]] = {
		["SFKRethilgore"] = { BB["Rethilgore"], "AtlasLootItems" },
		["SFKFelSteed"] = { AL["Fel Steed"], "AtlasLootItems" },
		["SFKJordansHammer"] = { AL["Jordan's Hammer"], "AtlasLootItems" },
		["SFKRazorclawtheButcher"] = { BB["Razorclaw the Butcher"], "AtlasLootItems" },
		["SFKSilverlaine"] = { BB["Baron Silverlaine"], "AtlasLootItems" },
		["SFKSpringvale"] = { BB["Commander Springvale"], "AtlasLootItems" },
		["SFKSever"] = { BB["Sever"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
		["SFKOdotheBlindwatcher"] = { BB["Odo the Blindwatcher"], "AtlasLootItems" },
		["SFKFenrustheDevourer"] = { BB["Fenrus the Devourer"], "AtlasLootItems" },
		["SFKBookofUr"] = { AL["The Book of Ur"], "AtlasLootItems" },
		["SFKArugalsVoidwalker"] = { AL["Arugal's Voidwalker"], "AtlasLootItems" },
		["SFKWolfMasterNandos"] = { BB["Wolf Master Nandos"], "AtlasLootItems" },
		["SFKArchmageArugal"] = { BB["Archmage Arugal"], "AtlasLootItems" },
		["SFKDeathswornCaptain"] = { BB["Deathsworn Captain"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["SFKTrash"] = { AL["Trash Mobs"].." ("..BZ["Shadowfang Keep"]..")", "AtlasLootItems" },
	},
	[BZ["The Stockade"]] = {
		["SWStKamDeepfury"] = { BB["Kam Deepfury"], "AtlasLootItems" },
		["SWStBruegalIronknuckle"] = { BB["Bruegal Ironknuckle"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["SWStTrash"] = { AL["Trash Mobs"].." ("..BZ["The Stockade"]..")", "AtlasLootItems" },
	},
	[BZ["Stratholme"]] = {
		["STRATSkull"] = { BB["Skul"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["STRATStratholmeCourier"] = { BB["Stratholme Courier"], "AtlasLootItems" },
		["STRATPostmaster"] = { BB["Postmaster Malown"], "AtlasLootItems" },
		["STRATFrasSiabi"] = { AL["Fras Siabi"], "AtlasLootItems" },
		["STRATAtiesh"] = { "Atiesh", "AtlasLootItems" },
		["STRATBalzaphon"] = { BB["Balzaphon"].." ("..AL["Scourge Invasion"]..")", "AtlasLootItems" },
		["STRATHearthsingerForresten"] = { BB["Hearthsinger Forresten"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["STRATTheUnforgiven"] = { BB["The Unforgiven"], "AtlasLootItems" },
		["STRATTimmytheCruel"] = { BB["Timmy the Cruel"], "AtlasLootItems" },
		["STRATMalorsStrongbox"] = { AL["Malor's Strongbox"], "AtlasLootItems" },
		["STRATCrimsonHammersmith"] = { AL["Crimson Hammersmith"].." ("..AL["Summon"]..")", "AtlasLootItems" },
		["STRATBSPlansSerenity"] = { "Plans: Serenity", "AtlasLootItems" },
		["STRATCannonMasterWilley"] = { BB["Cannon Master Willey"], "AtlasLootItems" },
		["STRATArchivistGalford"] = { BB["Archivist Galford"], "AtlasLootItems" },
		["STRATBalnazzar"] = { BB["Balnazzar"], "AtlasLootItems" },
		["STRATSothosJarien"] = { BB["Sothos"].." & "..BB["Jarien"], "AtlasLootItems" },
		["STRATStonespine"] = { BB["Stonespine"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["STRATNerubenkan"] = { BB["Nerub'enkan"], "AtlasLootItems" },
		["STRATBaronessAnastari"] = { BB["Baroness Anastari"], "AtlasLootItems" },
		["STRATBlackGuardSwordsmith"] = { AL["Black Guard Swordsmith"].." ("..AL["Summon"]..")", "AtlasLootItems" },
		["STRATBSPlansCorruption"] = { "Plans: Corruption", "AtlasLootItems" },
		["STRATMalekithePallid"] = { BB["Maleki the Pallid"], "AtlasLootItems" },
		["STRATMagistrateBarthilas"] = { BB["Magistrate Barthilas"], "AtlasLootItems" },
		["STRATRamsteintheGorger"] = { BB["Ramstein the Gorger"], "AtlasLootItems" },
		["STRATBaronRivendare"] = { BB["Baron Rivendare"], "AtlasLootItems" },
		["STRATTrash"] = { AL["Trash Mobs"].." ("..BZ["Stratholme"]..")", "AtlasLootItems" },
	},
	[AL["The Sunken Temple"]] = {
		["STSpawnOfHakkar"] = { AL["Spawn of Hakkar"], "AtlasLootItems" },
		["STBalconyMinibosses"] = { AL["Balcony Minibosses"], "AtlasLootItems" },
		["STAtalalarion"] = { BB["Atal'alarion"], "AtlasLootItems" },
		["STDreamscythe"] = { BB["Dreamscythe"], "AtlasLootItems" },
		["STWeaver"] = { BB["Weaver"], "AtlasLootItems" },
		["STAvatarofHakkar"] = { BB["Avatar of Hakkar"], "AtlasLootItems" },
		["STJammalan"] = { BB["Jammal'an the Prophet"], "AtlasLootItems" },
		["STOgom"] = { BB["Ogom the Wretched"], "AtlasLootItems" },
		["STMorphaz"] = { BB["Morphaz"], "AtlasLootItems" },
		["STHazzas"] = { BB["Hazzas"], "AtlasLootItems" },
		["STEranikus"] = { BB["Shade of Eranikus"], "AtlasLootItems" },
		["STTrash"] = { AL["Trash Mobs"].." ("..AL["The Sunken Temple"]..")", "AtlasLootItems" },
	},
	[BZ["Temple of Ahn'Qiraj"]] = {
		["AQ40Skeram"] = { BB["The Prophet Skeram"], "AtlasLootItems" },
		["AQ40Trio"] = { AL["The Bug Family"], "AtlasLootItems" },
		["AQ40Sartura"] = { BB["Battleguard Sartura"], "AtlasLootItems" },
		["AQ40Fankriss"] = { BB["Fankriss the Unyielding"], "AtlasLootItems" },
		["AQ40Viscidus"] = { BB["Viscidus"], "AtlasLootItems" },
		["AQ40Huhuran"] = { BB["Princess Huhuran"], "AtlasLootItems" },
		["AQ40Emperors"] = { BB["The Twin Emperors"], "AtlasLootItems" },
		["AQ40Ouro"] = { BB["Ouro"], "AtlasLootItems" },
		["AQ40CThun"] = { BB["C'Thun"], "AtlasLootItems" },
		["AQ40Trash1"] = { AL["Trash Mobs"].." (AQ40)", "AtlasLootItems" },
		["AQ40Trash2"] = { AL["Trash Mobs"].." (AQ40)", "AtlasLootItems" },
		["AQOpening"] = { "AQ Opening Quest Line", "AtlasLootItems" },
	},
	[BZ["Uldaman"].." ("..AL["Entrance"]..")"] = {
		["UldMagreganDeepshadow"] = { AL["Magregan Deepshadow"], "AtlasLootItems" },
		["UldTabletofRyuneh"] = { "Tablet of Ryun'eh", "AtlasLootItems" },
		["UldKromStoutarmChest"] = { AL["Krom Stoutarm's Chest"], "AtlasLootItems" },
		["UldGarrettFamilyChest"] = { AL["Garrett Family Chest"], "AtlasLootItems" },
		["UldShovelphlange"] = { AL["Digmaster Shovelphlange"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	},
	[BZ["Uldaman"]] = {
		["UldRevelosh"] = { BB["Revelosh"], "AtlasLootItems" },
		["UldEric"] = { BB["Baelog"], "AtlasLootItems" },
		["UldOlaf"] = { BB["Baelog"], "AtlasLootItems" },
		["UldBaelog"] = { BB["Baelog"], "AtlasLootItems" },
		["UldBaelogsChest"] = { BB["Baelog"], "AtlasLootItems" },
		["UldIronaya"] = { BB["Ironaya"], "AtlasLootItems" },
		["UldObsidianSentinel"] = { BB["Obsidian Sentinel"], "AtlasLootItems" },
		["UldAncientStoneKeeper"] = { BB["Ancient Stone Keeper"], "AtlasLootItems" },
		["UldGalgannFirehammer"] = { BB["Galgann Firehammer"], "AtlasLootItems" },
		["UldTabletofWill"] = { "Tablet of Will", "AtlasLootItems" },
		["UldShadowforgeCache"] = { "Shadowforge Cache", "AtlasLootItems" },
		["UldGrimlok"] = { BB["Grimlok"], "AtlasLootItems" },
		["UldArchaedas"] = { BB["Archaedas"], "AtlasLootItems" },
		["UldTrash"] = { AL["Trash Mobs"].." ("..BZ["Uldaman"]..")", "AtlasLootItems" },
	},
	[BZ["Wailing Caverns"].." ("..AL["Entrance"]..")"] = {
		["WCKalldanFelmoon"] = { AL["Kalldan Felmoon"], "AtlasLootItems" },
		["WCMadMagglish"] = { AL["Mad Magglish"], "AtlasLootItems" },
		["WCTrigoretheLasher"] = { AL["Trigore the Lasher"].." ("..AL["Rare"]..")", "AtlasLootItems" },
	},
	[BZ["Wailing Caverns"]] = {
		["WCBoahn"] = { AL["Boahn"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["WCLordCobrahn"] = { BB["Lord Cobrahn"], "AtlasLootItems" },
		["WCLadyAnacondra"] = { BB["Lady Anacondra"], "AtlasLootItems" },
		["WCKresh"] = { BB["Kresh"], "AtlasLootItems" },
		["WCLordPythas"] = { BB["Lord Pythas"], "AtlasLootItems" },
		["WCSkum"] = { BB["Skum"], "AtlasLootItems" },
		["WCLordSerpentis"] = { BB["Lord Serpentis"], "AtlasLootItems" },
		["WCVerdan"] = { BB["Verdan the Everliving"], "AtlasLootItems" },
		["WCMutanus"] = { BB["Mutanus the Devourer"], "AtlasLootItems" },
		["WCDeviateFaerieDragon"] = { BB["Deviate Faerie Dragon"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["WCTrash"] = { AL["Trash Mobs"].." ("..BZ["Wailing Caverns"]..")", "AtlasLootItems" },
	},
	[BZ["Zul'Farrak"]] = {
		["ZFAntusul"] = { BB["Antu'sul"], "AtlasLootItems" },
		["ZFThekatheMartyr"] = { AL["Theka the Martyr"], "AtlasLootItems" },
		["ZFWitchDoctorZumrah"] = { BB["Witch Doctor Zum'rah"], "AtlasLootItems" },
		["ZFNekrumGutchewer"] = { AL["Nekrum Gutchewer"], "AtlasLootItems" },
		["ZFSezzziz"] = { BB["Shadowpriest Sezz'ziz"], "AtlasLootItems" },
		["ZFDustwraith"] = { AL["Dustwraith"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["ZFSergeantBly"] = { AL["Sergeant Bly"], "AtlasLootItems" },
		["ZFSandfury"] = { AL["Sandfury Executioner"], "AtlasLootItems" },
		["ZFHydromancerVelratha"] = { AL["Hydromancer Velratha"], "AtlasLootItems" },
		["ZFGahzrilla"] = { BB["Gahz'rilla"], "AtlasLootItems" },
		["ZFChiefUkorzSandscalp"] = { BB["Chief Ukorz Sandscalp"], "AtlasLootItems" },
		["ZFZerillis"] = { AL["Zerillis"].." ("..AL["Rare"]..")", "AtlasLootItems" },
		["ZFTrash"] = { AL["Trash Mobs"].." ("..BZ["Zul'Farrak"]..")", "AtlasLootItems" },
	},
	[BZ["Zul'Gurub"]] = {
		["ZGJeklik"] = { BB["High Priestess Jeklik"], "AtlasLootItems" },
		["ZGVenoxis"] = { BB["High Priest Venoxis"], "AtlasLootItems" },
		["ZGMarli"] = { BB["High Priestess Mar'li"], "AtlasLootItems" },
		["ZGMandokir"] = { BB["Bloodlord Mandokir"], "AtlasLootItems" },
		["ZGGrilek"] = { BB["Gri'lek"], "AtlasLootItems" },
		["ZGHazzarah"] = { BB["Hazza'rah"], "AtlasLootItems" },
		["ZGRenataki"] = { BB["Renataki"], "AtlasLootItems" },
		["ZGWushoolay"] = { BB["Wushoolay"], "AtlasLootItems" },
		["ZGGahzranka"] = { BB["Gahz'ranka"], "AtlasLootItems" },
		["ZGThekal"] = { BB["High Priest Thekal"], "AtlasLootItems" },
		["ZGArlokk"] = { BB["High Priestess Arlokk"], "AtlasLootItems" },
		["ZGJindo"] = { BB["Jin'do the Hexxer"], "AtlasLootItems" },
		["ZGHakkar"] = { BB["Hakkar"], "AtlasLootItems" },
		["ZGMuddyChurningWaters"] = { AL["Muddy Churning Waters"], "AtlasLootItems" },
		["ZGJinxedHoodooPile"] = { AL["Jinxed Hoodoo Pile"], "AtlasLootItems" },
		["ZGShared"] = { "Shared ZG Priest Drops", "AtlasLootItems" },
		["ZGTrash1"] = { AL["Trash Mobs"].." ("..BZ["Zul'Gurub"]..")", "AtlasLootItems" },
		["ZGTrash2"] = { AL["Trash Mobs"].." ("..BZ["Zul'Gurub"]..")", "AtlasLootItems" },
		["ZGEnchants"] = { "ZG Enchants", "AtlasLootItems" },
	},
	
	------------
	--- Sets ---
	------------
	
	[AL["Sets"]] = {
		["DEADMINES"] = { AL["Set: "]..BIS["Defias Leather"], "AtlasLootSetItems" },
		["WAILING"] = { AL["Set: "]..BIS["Embrace of the Viper"], "AtlasLootSetItems" },
		["SCARLET"] = { AL["Set: "]..BIS["Chain of the Scarlet Crusade"], "AtlasLootSetItems" },
		["BLACKROCKD"] = { AL["Set: "]..BIS["The Gladiator"], "AtlasLootSetItems" },
		["IRONWEAVE"] = { AL["Set: "]..BIS["Ironweave Battlesuit"], "AtlasLootSetItems" },
		["ScholoCloth"] = { AL["Set: "]..BIS["Necropile Raiment"], "AtlasLootSetItems" },
		["ScholoLeather"] = { AL["Set: "]..BIS["Cadaverous Garb"], "AtlasLootSetItems" },
		["ScholoMail"] = { AL["Set: "]..BIS["Bloodmail Regalia"], "AtlasLootSetItems" },
		["ScholoPlate"] = { AL["Set: "]..BIS["Deathbone Guardian"], "AtlasLootSetItems" },
		["STRAT"] = { AL["Set: "]..BIS["The Postmaster"], "AtlasLootSetItems" },
		["SpiderKiss"] = { AL["Set: "]..BIS["Spider's Kiss"], "AtlasLootSetItems" },
		["DalRend"] = { AL["Set: "]..BIS["Dal'Rend's Arms"], "AtlasLootSetItems" },
		["ZGRings"] = { AL["Set: "]..AL["Zul'Gurub Rings"], "AtlasLootSetItems" },
		["ShardOfGods"] = { AL["Set: "]..BIS["Shard of the Gods"], "AtlasLootSetItems" },
		["SpiritofEskhandar"] = { AL["Set: "]..BIS["Spirit of Eskhandar"], "AtlasLootSetItems" },
		["HakkariBlades"] = { AL["Set: "]..BIS["The Twin Blades of Hakkari"], "AtlasLootSetItems" },
		["PrimalBlessing"] = { AL["Set: "]..BIS["Primal Blessing"], "AtlasLootSetItems" },
		["ScourgeInvasion"] = { AL["Set: "]..AL["Scourge Invasion"], "AtlasLootSetItems" },
		["Legendaries"] = { AL["Set: "]..AL["Legendary Items"], "AtlasLootSetItems" },
		["Artifacts"] = { AL["Set: "]..AL["Artifact Items"], "AtlasLootSetItems" },
		["RareMounts"] = { AL["Rare Mounts"], "AtlasLootSetItems" },
		["OldMounts"] = { AL["Old Mounts"], "AtlasLootSetItems" },
		["PvPMountsSets"] = { AL["PvP Mounts"], "AtlasLootSetItems" },
		["UnobMounts"] = { AL["Unobtainable Mounts"], "AtlasLootSetItems" },
		["Tabards"] = { AL["Tabards"], "AtlasLootSetItems" },
		["RarePets1"] = { AL["Rare Pets"], "AtlasLootSetItems" },
		["RarePets2"] = { AL["Rare Pets"], "AtlasLootSetItems" },
		["WorldEpics1"] = { AL["World Epics"].." - "..AL["Level 30-39"], "AtlasLootSetItems" },
		["WorldEpics2"] = { AL["World Epics"].." - "..AL["Level 40-49"], "AtlasLootSetItems" },
		["WorldEpics3"] = { AL["World Epics"].." - "..AL["Level 50-60"], "AtlasLootSetItems" },
	},
	[AL["Crafted Sets - Blacksmithing"]] = {
		["ImperialPlate"] = { BIS["Imperial Plate"], "AtlasLootCrafting" },
		["TheDarksoul"] = { BIS["The Darksoul"], "AtlasLootCrafting" },
		["BloodsoulEmbrace"] = { BIS["Bloodsoul Embrace"], "AtlasLootCrafting" },
	},
	[AL["Crafted Sets - Tailoring"]] = {
		["BloodvineG"] = { BIS["Bloodvine Garb"], "AtlasLootCrafting" },
	},
	[AL["Crafted Sets - Leatherworking"]] = {
		["VolcanicArmor"] = { BIS["Volcanic Armor"], "AtlasLootCrafting" },
		["IronfeatherArmor"] = { BIS["Ironfeather Armor"], "AtlasLootCrafting" },
		["StormshroudArmor"] = { BIS["Stormshroud Armor"], "AtlasLootCrafting" },
		["DevilsaurArmor"] = { BIS["Devilsaur Armor"], "AtlasLootCrafting" },
		["BloodTigerH"] = { BIS["Blood Tiger Harness"], "AtlasLootCrafting" },
		["PrimalBatskin"] = { BIS["Primal Batskin"], "AtlasLootCrafting" },
		["GreenDragonM"] = { BIS["Green Dragon Mail"], "AtlasLootCrafting" },
		["BlueDragonM"] = { BIS["Blue Dragon Mail"], "AtlasLootCrafting" },
		["BlackDragonM"] = { BIS["Black Dragon Mail"], "AtlasLootCrafting" },
	},
	[AL["Zul'Gurub Sets"]] = {
		["ZGDruid"] = { BC["Druid"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGHunter"] = { BC["Hunter"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGMage"] = { BC["Mage"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGPaladin"] = { BC["Paladin"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGPriest"] = { BC["Priest"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGRogue"] = { BC["Rogue"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGShaman"] = { BC["Shaman"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGWarlock"] = { BC["Warlock"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
		["ZGWarrior"] = { BC["Warrior"].." - "..AL["ZG Class Sets"], "AtlasLootSetItems" },
	},
	[AL["Ruins of Ahn'Qiraj Sets"]] = {
		["AQ20Mage"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Warlock"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Priest"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Rogue"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Druid"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Hunter"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Paladin"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Shaman"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
		["AQ20Warrior"] = { AL["AQ20 Class Sets"], "AtlasLootSetItems" },
	},
	[AL["Temple of Ahn'Qiraj Sets"]] = {
		["AQ40Mage"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Priest"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Warlock"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Rogue"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Druid"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Shaman"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Hunter"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Warrior"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
		["AQ40Paladin"] = { AL["AQ40 Class Sets"], "AtlasLootSetItems" },
	},
	[AL["Tier 0/0.5 Sets"]] = {
		["T0Druid"] = { BC["Druid"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Hunter"] = { BC["Hunter"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Mage"] = { BC["Mage"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Paladin"] = { BC["Paladin"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Priest"] = { BC["Priest"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Rogue"] = { BC["Rogue"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Shaman"] = { BC["Shaman"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Warlock"] = { BC["Warlock"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
		["T0Warrior"] = { BC["Warrior"].." - "..AL["Tier 0/0.5 Sets"], "AtlasLootSetItems" },
	},
	[AL["Tier 1 Sets"]] = {
		["T1Druid"] = { BC["Druid"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Hunter"] = { BC["Hunter"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Mage"] = { BC["Mage"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Paladin"] = { BC["Paladin"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Priest"] = { BC["Priest"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Rogue"] = { BC["Rogue"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Shaman"] = { BC["Shaman"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Warlock"] = { BC["Warlock"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
		["T1Warrior"] = { BC["Warrior"].." - "..AL["Tier 1 Sets"], "AtlasLootSetItems" },
	},
	[AL["Tier 2 Sets"]] = {
		["T2Druid"] = { BC["Druid"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Hunter"] = { BC["Hunter"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Mage"] = { BC["Mage"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Paladin"] = { BC["Paladin"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Priest"] = { BC["Priest"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Rogue"] = { BC["Rogue"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Shaman"] = { BC["Shaman"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Warlock"] = { BC["Warlock"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
		["T2Warrior"] = { BC["Warrior"].." - "..AL["Tier 2 Sets"], "AtlasLootSetItems" },
	},
	[AL["Tier 3 Sets"]] = {
		["T3Druid"] = { BC["Druid"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Hunter"] = { BC["Hunter"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Mage"] = { BC["Mage"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Paladin"] = { BC["Paladin"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Priest"] = { BC["Priest"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Rogue"] = { BC["Rogue"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Shaman"] = { BC["Shaman"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Warlock"] = { BC["Warlock"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
		["T3Warrior"] = { BC["Warrior"].." - "..AL["Tier 3 Sets"], "AtlasLootSetItems" },
	},
	
	------------------------
	--- Misc Collections ---
	------------------------
	
	
	--------------------
	--- World Bosses ---
	--------------------
	
	[AL["World Bosses"]] = {
		["AAzuregos"] = { BB["Azuregos"], "AtlasLootWBItems" },
		["ASpiritA"] = { AL["Spirit of Azuregos"], "AtlasLootWBItems" },
		["KKazzak"] = { BB["Lord Kazzak"], "AtlasLootWBItems" },
		--Emrald Dragons
		["DEmeriss"] = { BB["Emeriss"], "AtlasLootWBItems" },
		["DLethon"] = { BB["Lethon"], "AtlasLootWBItems" },
		["DTaerar"] = { BB["Taerar"], "AtlasLootWBItems" },
		["DYsondre"] = { BB["Ysondre"], "AtlasLootWBItems" },
		["DTrash"] = { AL["Trash Mobs"].." ("..AL["Emerald Dragons"]..")", "AtlasLootWBItems" },
	},
	
	--------------
	--- Events ---
	--------------
	
	[AL["World Events"]] = {
		["AbyssalTemplars"] = { "Abyssal Council - Templars", "AtlasLootWorldEvents" },
		["AbyssalDukes"] = { "Abyssal Council - Dukes", "AtlasLootWorldEvents" },
		["AbyssalLords"] = { "Abyssal Council - High Council", "AtlasLootWorldEvents" },
		--Seasonal
		["ChildrensWeek"] = { AL["Children's Week"], "AtlasLootWorldEvents" },
		["Halloween1"] = { AL["Hallow's End"], "AtlasLootWorldEvents" },
		["Halloween2"] = { AL["Hallow's End"], "AtlasLootWorldEvents" },
		["HarvestFestival"] = { AL["Harvest Festival"], "AtlasLootWorldEvents" },
		["LunarFestival1"] = { AL["Lunar Festival"], "AtlasLootWorldEvents" },
		["LunarFestival2"] = { AL["Lunar Festival"], "AtlasLootWorldEvents" },
		["MidsummerFestival"] = { AL["Midsummer Fire Festival"], "AtlasLootWorldEvents" },
		["Noblegarden"] = { AL["Noblegarden"], "AtlasLootWorldEvents" },
		["Valentineday"] = { AL["Love is in the Air"], "AtlasLootWorldEvents" },
		["Winterviel1"] = { AL["Feast of Winter Veil"], "AtlasLootWorldEvents" },
		["Winterviel2"] = { AL["Feast of Winter Veil"], "AtlasLootWorldEvents" },
		--Other
		["ElementalInvasion"] = { AL["Elemental Invasion"], "AtlasLootWorldEvents" },
		["FishingExtravaganza"] = { AL["Stranglethorn Fishing Extravaganza"], "AtlasLootWorldEvents" },
		["GurubashiArena"] = { AL["Gurubashi Arena Booty Run"], "AtlasLootWorldEvents" },
		["ScourgeInvasionEvent1"] = { AL["Scourge Invasion"], "AtlasLootWorldEvents" },
		["ScourgeInvasionEvent2"] = { AL["Scourge Invasion Bosses"], "AtlasLootWorldEvents" },
	},
	
	------------------------
	--- Classic Factions ---
	------------------------
	[AL["Factions"]] = {
		--Argent Dawn
		["Argent1"] = { BF["Argent Dawn"]..": Token Hand-ins", "AtlasLootRepItems" },
		["Argent2"] = { BF["Argent Dawn"], "AtlasLootRepItems" },
		["Argent3"] = { BF["Argent Dawn"], "AtlasLootRepItems" },
		--Bloodsail Buccaneers
		["Bloodsail1"] = { BF["Bloodsail Buccaneers"], "AtlasLootRepItems" },
		--Brood of Nozdormu
		["AQBroodRings"] = { BF["Brood of Nozdormu"], "AtlasLootRepItems" },
		--Cenarion Circle
		["Cenarion1"] = { BF["Cenarion Circle"]..": "..BF["Friendly"], "AtlasLootRepItems" },
		["Cenarion2"] = { BF["Cenarion Circle"]..": "..BF["Honored"], "AtlasLootRepItems" },
		["Cenarion3"] = { BF["Cenarion Circle"]..": "..BF["Revered"], "AtlasLootRepItems" },
		["Cenarion4"] = { BF["Cenarion Circle"]..": "..BF["Exalted"], "AtlasLootRepItems" },
		--The Darkmoon Faire
		["Darkmoon"] = { BF["Darkmoon Faire"], "AtlasLootRepItems" },
		--The Defilers
		["Defilers"] = { BF["The Defilers"], "AtlasLootRepItems" },
		--Frostwolf Clan
		["Frostwolf1"] = { BF["Frostwolf Clan"], "AtlasLootRepItems" },
		--Hydraxian Waterlords
		["WaterLords1"] = { BF["Hydraxian Waterlords"], "AtlasLootRepItems" },
		--Gelkis Clan Centaur
		["GelkisClan1"] = { BF["Gelkis Clan Centaur"], "AtlasLootRepItems" },
		--The League of Arathor
		["LeagueofArathor"] = { BF["The League of Arathor"], "AtlasLootRepItems" },
		--Magram Clan Centaur
		["MagramClan1"] = { BF["Magram Clan Centaur"], "AtlasLootRepItems" },
		--Stormpike Guard
		["Stormpike1"] = { BF["Stormpike Guard"], "AtlasLootRepItems" },
		--Thorium Brotherhood
		["Thorium1"] = { BF["Thorium Brotherhood"]..": "..BF["Friendly"].."/"..BF["Honored"], "AtlasLootRepItems" },
		["Thorium2"] = { BF["Thorium Brotherhood"]..": "..BF["Revered"].."/"..BF["Exalted"], "AtlasLootRepItems" },
		--Timbermaw Hold
		["Timbermaw"] = { BF["Timbermaw Hold"], "AtlasLootRepItems" },
		--Wintersaber Trainers
		["Wintersaber1"] = { BF["Wintersaber Trainers"], "AtlasLootRepItems" },
		--Zandalar Tribe
		["Zandalar1"] = { BF["Zandalar Tribe"]..": "..BF["Friendly"].."/"..BF["Honored"], "AtlasLootRepItems" },
		["Zandalar2"] = { BF["Zandalar Tribe"]..": "..BF["Revered"].."/"..BF["Exalted"], "AtlasLootRepItems" },
	},
	
	--------------
	--- Trades ---
	--------------
	[AL["Professions"]] = {
		["CraftedWeapons1"] = { AL["Crafted Epic Weapons"], "AtlasLootCrafting" },
		--Alchemy
		["AlchemyApprentice1"] = { BS["Alchemy"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
		["AlchemyJourneyman1"] = { BS["Alchemy"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["AlchemyExpert1"] = { BS["Alchemy"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["AlchemyArtisan1"] = { BS["Alchemy"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["AlchemyArtisan2"] = { BS["Alchemy"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		--BlackSmithing
		["SmithingApprentice1"] = { BS["Blacksmithing"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
		["SmithingJourneyman1"] = { BS["Blacksmithing"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["SmithingJourneyman2"] = { BS["Blacksmithing"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["SmithingExpert1"] = { BS["Blacksmithing"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["SmithingExpert2"] = { BS["Blacksmithing"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["SmithingArtisan1"] = { BS["Blacksmithing"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["SmithingArtisan2"] = { BS["Blacksmithing"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["SmithingArtisan3"] = { BS["Blacksmithing"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["Armorsmith1"] = { BS["Armorsmith"], "AtlasLootCrafting" },
		["Weaponsmith1"] = { BS["Weaponsmith"], "AtlasLootCrafting" },
		["Axesmith1"] = { AL["Master Axesmith"], "AtlasLootCrafting" },
		["Hammersmith1"] = { AL["Master Hammersmith"], "AtlasLootCrafting" },
		["Swordsmith1"] = { AL["Master Swordsmith"], "AtlasLootCrafting" },
		--Enchanting
		["EnchantingApprentice1"] = { BS["Enchanting"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
		["EnchantingJourneyman1"] = { BS["Enchanting"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["EnchantingJourneyman2"] = { BS["Enchanting"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["EnchantingExpert1"] = { BS["Enchanting"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["EnchantingExpert2"] = { BS["Enchanting"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["EnchantingArtisan1"] = { BS["Enchanting"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["EnchantingArtisan2"] = { BS["Enchanting"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["EnchantingArtisan3"] = { BS["Enchanting"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		--Engineering
		["EngineeringApprentice1"] = { BS["Engineering"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
		["EngineeringJourneyman1"] = { BS["Engineering"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["EngineeringJourneyman2"] = { BS["Engineering"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["EngineeringExpert1"] = { BS["Engineering"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["EngineeringExpert2"] = { BS["Engineering"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["EngineeringArtisan1"] = { BS["Engineering"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["EngineeringArtisan2"] = { BS["Engineering"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["Gnomish1"] = { AL["Gnomish Engineering"], "AtlasLootCrafting" },
		["Goblin1"] = { AL["Goblin Engineering"], "AtlasLootCrafting" },
		--Leatherworking
		["LeatherApprentice1"] = { BS["Leatherworking"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
		["LeatherJourneyman1"] = { BS["Leatherworking"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["LeatherJourneyman2"] = { BS["Leatherworking"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["LeatherExpert1"] = { BS["Leatherworking"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["LeatherExpert2"] = { BS["Leatherworking"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["LeatherArtisan1"] = { BS["Leatherworking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["LeatherArtisan2"] = { BS["Leatherworking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["LeatherArtisan3"] = { BS["Leatherworking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["Dragonscale1"] = { BS["Dragonscale Leatherworking"], "AtlasLootCrafting" },
		["Elemental1"] = { BS["Elemental Leatherworking"], "AtlasLootCrafting" },
		["Tribal1"] = { BS["Tribal Leatherworking"], "AtlasLootCrafting" },
		--Mining
		["Mining1"] = { BS["Mining"], "AtlasLootCrafting" },
		["Mining2"] = { BS["Mining"], "AtlasLootCrafting" },
		["Smelting1"] = { BS["Smelting"], "AtlasLootCrafting" },
		["Herbalism1"] = { BS["Herbalism"], "AtlasLootCrafting" },
		["Herbalism2"] = { BS["Herbalism"], "AtlasLootCrafting" },
		--Tailoring
		["TailoringApprentice1"] = { BS["Tailoring"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
		["TailoringJourneyman1"] = { BS["Tailoring"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["TailoringJourneyman2"] = { BS["Tailoring"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["TailoringExpert1"] = { BS["Tailoring"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["TailoringExpert2"] = { BS["Tailoring"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["TailoringArtisan1"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["TailoringArtisan2"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["TailoringArtisan3"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		["TailoringArtisan4"] = { BS["Tailoring"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		--Cooking
		["CookingApprentice1"] = { BS["Cooking"]..": "..AL["Apprentice"], "AtlasLootCrafting" },
		["CookingJourneyman1"] = { BS["Cooking"]..": "..AL["Journeyman"], "AtlasLootCrafting" },
		["CookingExpert1"] = { BS["Cooking"]..": "..AL["Expert"], "AtlasLootCrafting" },
		["CookingArtisan1"] = { BS["Cooking"]..": "..AL["Artisan"], "AtlasLootCrafting" },
		--FirstAid
		["FirstAid1"] = { BS["First Aid"], "AtlasLootCrafting" },
		--Poisons
		["Poisons1"] = { BC["Rogue"]..": "..BS["Poisons"], "AtlasLootCrafting" },
	},
	
	-----------
	--- PvP ---
	-----------
	
	[AL["Battlegrounds"]] = {
		--Alterac Valley
		["AVRepFriendly"] = { BZ["Alterac Valley"].." 51-60 "..AL["Friendly Rewards"], "AtlasLootBGItems" },
		["AVRepHonored"] = { BZ["Alterac Valley"].." 51-60 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["AVRepRevered"] = { BZ["Alterac Valley"].." 51-60 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["AVRepExalted"] = { BZ["Alterac Valley"].." 51-60 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
		--Arathi Basin
		["ABRepFriendly"] = { BZ["Arathi Basin"].." Friendly Rewards", "AtlasLootBGItems" },
		["ABRepHonored2029"] = { BZ["Arathi Basin"].." 20-29 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["ABRepHonored3039"] = { BZ["Arathi Basin"].." 30-39 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["ABRepHonored4049"] = { BZ["Arathi Basin"].." 40-49 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["ABRepHonored5059"] = { BZ["Arathi Basin"].." 50-59 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["ABRepRevered2029"] = { BZ["Arathi Basin"].." 20-29 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["ABRepRevered3039"] = { BZ["Arathi Basin"].." 30-39 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["ABRepRevered4049"] = { BZ["Arathi Basin"].." 40-49 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["ABRepRevered5059"] = { BZ["Arathi Basin"].." 50-59 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["ABRepExalted"] = { BZ["Arathi Basin"].." 60 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
		--Warsong Gulch
		["WSGRepFriendly"] = { BZ["Warsong Gulch"].." Friendly Rewards", "AtlasLootBGItems" },
		["WSGRepHonored1019"] = { BZ["Warsong Gulch"].." 10-19 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["WSGRepHonored2029"] = { BZ["Warsong Gulch"].." 20-29 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["WSGRepHonored3039"] = { BZ["Warsong Gulch"].." 30-39 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["WSGRepHonored4049"] = { BZ["Warsong Gulch"].." 40-49 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["WSGRepHonored5059"] = { BZ["Warsong Gulch"].." 50-59 "..AL["Honored Rewards"], "AtlasLootBGItems" },
		["WSGRepRevered1019"] = { BZ["Warsong Gulch"].." 10-19 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["WSGRepRevered2029"] = { BZ["Warsong Gulch"].." 20-29 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["WSGRepRevered3039"] = { BZ["Warsong Gulch"].." 30-39 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["WSGRepRevered4049"] = { BZ["Warsong Gulch"].." 40-49 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["WSGRepRevered5059"] = { BZ["Warsong Gulch"].." 50-59 "..AL["Revered Rewards"], "AtlasLootBGItems" },
		["WSGRepExalted4049"] = { BZ["Warsong Gulch"].." 40-49 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
		["WSGRepExalted5059"] = { BZ["Warsong Gulch"].." 50-59 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
		["WSGRepExalted60"] = { BZ["Warsong Gulch"].." 60 "..AL["Exalted Rewards"], "AtlasLootBGItems" },
	},
	["PvP"] = {
		--Misc Other PvP
		["PvP60Accessories1"] = { AL["PvP Accessories"], "AtlasLootGeneralPvPItems" },
		["PvP60Accessories2"] = { AL["PvP Accessories - Alliance"], "AtlasLootGeneralPvPItems" },
		["PvP60Accessories3"] = { AL["PvP Accessories - Horde"], "AtlasLootGeneralPvPItems" },
		["PVPWeapons1"] = { AL["Rank 14 Weapons"], "AtlasLootGeneralPvPItems" },
		["PVPWeapons2"] = { AL["Rank 14 Weapons"], "AtlasLootGeneralPvPItems" },
		["PvPMountsPvP"] = { AL["PvP Mounts"], "AtlasLootGeneralPvPItems" },
		--Level 60 PvP Sets
		["PVPDruid"] = { BC["Druid"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPHunter"] = { BC["Hunter"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPMage"] = { BC["Mage"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPPaladin"] = { BC["Paladin"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPPriest"] = { BC["Priest"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPRogue"] = { BC["Rogue"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPShaman"] = { BC["Shaman"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPWarlock"] = { BC["Warlock"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
		["PVPWarrior"] = { BC["Warrior"].." - "..AL["PvP Sets"], "AtlasLootGeneralPvPItems" },
	},
};